Class: Aws::GroundStation::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::GroundStation::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-groundstation/client.rb,
sig/client.rbs
Overview
An API client for GroundStation. To construct a client, you need to configure a :region and :credentials.
client = Aws::GroundStation::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelContactResponseSuccess, _CreateConfigResponseSuccess, _CreateDataflowEndpointGroupResponseSuccess, _CreateDataflowEndpointGroupV2ResponseSuccess, _CreateEphemerisResponseSuccess, _CreateMissionProfileResponseSuccess, _DeleteConfigResponseSuccess, _DeleteDataflowEndpointGroupResponseSuccess, _DeleteEphemerisResponseSuccess, _DeleteMissionProfileResponseSuccess, _DescribeContactResponseSuccess, _DescribeContactVersionResponseSuccess, _DescribeEphemerisResponseSuccess, _GetAgentConfigurationResponseSuccess, _GetAgentTaskResponseUrlResponseSuccess, _GetConfigResponseSuccess, _GetDataflowEndpointGroupResponseSuccess, _GetMinuteUsageResponseSuccess, _GetMissionProfileResponseSuccess, _GetSatelliteResponseSuccess, _ListAntennasResponseSuccess, _ListConfigsResponseSuccess, _ListContactVersionsResponseSuccess, _ListContactsResponseSuccess, _ListDataflowEndpointGroupsResponseSuccess, _ListEphemeridesResponseSuccess, _ListGroundStationReservationsResponseSuccess, _ListGroundStationsResponseSuccess, _ListMissionProfilesResponseSuccess, _ListSatellitesResponseSuccess, _ListTagsForResourceResponseSuccess, _RegisterAgentResponseSuccess, _ReserveContactResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAgentStatusResponseSuccess, _UpdateConfigResponseSuccess, _UpdateContactResponseSuccess, _UpdateEphemerisResponseSuccess, _UpdateMissionProfileResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#cancel_contact(params = {}) ⇒ Types::ContactIdResponse
Cancels or stops a contact with a specified contact ID based on its position in the [contact lifecycle][1].
-
#create_config(params = {}) ⇒ Types::ConfigIdResponse
Creates a
Configwith the specifiedconfigDataparameters. -
#create_dataflow_endpoint_group(params = {}) ⇒ Types::DataflowEndpointGroupIdResponse
Creates a
DataflowEndpointgroup containing the specified list ofDataflowEndpointobjects. -
#create_dataflow_endpoint_group_v2(params = {}) ⇒ Types::CreateDataflowEndpointGroupV2Response
Creates a
DataflowEndpointgroup containing the specified list of Ground Station Agent based endpoints. -
#create_ephemeris(params = {}) ⇒ Types::EphemerisIdResponse
Create an ephemeris with your specified EphemerisData.
-
#create_mission_profile(params = {}) ⇒ Types::MissionProfileIdResponse
Creates a mission profile.
-
#delete_config(params = {}) ⇒ Types::ConfigIdResponse
Deletes a
Config. -
#delete_dataflow_endpoint_group(params = {}) ⇒ Types::DataflowEndpointGroupIdResponse
Deletes a dataflow endpoint group.
-
#delete_ephemeris(params = {}) ⇒ Types::EphemerisIdResponse
Delete an ephemeris.
-
#delete_mission_profile(params = {}) ⇒ Types::MissionProfileIdResponse
Deletes a mission profile.
-
#describe_contact(params = {}) ⇒ Types::DescribeContactResponse
Describes an existing contact.
-
#describe_contact_version(params = {}) ⇒ Types::DescribeContactVersionResponse
Describes a specific version of a contact.
-
#describe_ephemeris(params = {}) ⇒ Types::DescribeEphemerisResponse
Retrieve information about an existing ephemeris.
-
#get_agent_configuration(params = {}) ⇒ Types::GetAgentConfigurationResponse
For use by AWS Ground Station Agent and shouldn't be called directly. -
#get_agent_task_response_url(params = {}) ⇒ Types::GetAgentTaskResponseUrlResponse
For use by AWS Ground Station Agent and shouldn't be called directly. -
#get_config(params = {}) ⇒ Types::GetConfigResponse
Returns
Configinformation. -
#get_dataflow_endpoint_group(params = {}) ⇒ Types::GetDataflowEndpointGroupResponse
Returns the dataflow endpoint group.
-
#get_minute_usage(params = {}) ⇒ Types::GetMinuteUsageResponse
Returns the number of reserved minutes used by account.
-
#get_mission_profile(params = {}) ⇒ Types::GetMissionProfileResponse
Returns a mission profile.
-
#get_satellite(params = {}) ⇒ Types::GetSatelliteResponse
Returns a satellite.
-
#list_antennas(params = {}) ⇒ Types::ListAntennasResponse
Returns a list of antennas at a specified ground station.
-
#list_configs(params = {}) ⇒ Types::ListConfigsResponse
Returns a list of
Configobjects. -
#list_contact_versions(params = {}) ⇒ Types::ListContactVersionsResponse
Returns a list of versions for a specified contact.
-
#list_contacts(params = {}) ⇒ Types::ListContactsResponse
Returns a list of contacts.
-
#list_dataflow_endpoint_groups(params = {}) ⇒ Types::ListDataflowEndpointGroupsResponse
Returns a list of
DataflowEndpointgroups. -
#list_ephemerides(params = {}) ⇒ Types::ListEphemeridesResponse
List your existing ephemerides.
-
#list_ground_station_reservations(params = {}) ⇒ Types::ListGroundStationReservationsResponse
Returns a list of reservations for a specified ground station.
-
#list_ground_stations(params = {}) ⇒ Types::ListGroundStationsResponse
Returns a list of ground stations.
-
#list_mission_profiles(params = {}) ⇒ Types::ListMissionProfilesResponse
Returns a list of mission profiles.
-
#list_satellites(params = {}) ⇒ Types::ListSatellitesResponse
Returns a list of satellites.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a specified resource.
-
#register_agent(params = {}) ⇒ Types::RegisterAgentResponse
For use by AWS Ground Station Agent and shouldn't be called directly. -
#reserve_contact(params = {}) ⇒ Types::ContactIdResponse
Reserves a contact using specified parameters.
-
#tag_resource(params = {}) ⇒ Struct
Assigns a tag to a resource.
-
#untag_resource(params = {}) ⇒ Struct
Deassigns a resource tag.
-
#update_agent_status(params = {}) ⇒ Types::UpdateAgentStatusResponse
For use by AWS Ground Station Agent and shouldn't be called directly. -
#update_config(params = {}) ⇒ Types::ConfigIdResponse
Updates the
Configused when scheduling contacts. -
#update_contact(params = {}) ⇒ Types::UpdateContactResponse
Updates a specific contact.
-
#update_ephemeris(params = {}) ⇒ Types::EphemerisIdResponse
Update an existing ephemeris.
-
#update_mission_profile(params = {}) ⇒ Types::MissionProfileIdResponse
Updates a mission profile.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
-
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-groundstation/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3293 3294 3295 |
# File 'lib/aws-sdk-groundstation/client.rb', line 3293 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3296 3297 3298 |
# File 'lib/aws-sdk-groundstation/client.rb', line 3296 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3151 3152 3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 3165 3166 3167 |
# File 'lib/aws-sdk-groundstation/client.rb', line 3151 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::GroundStation') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-groundstation' context[:gem_version] = '1.88.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_contact(params = {}) ⇒ Types::ContactIdResponse
Cancels or stops a contact with a specified contact ID based on its position in the contact lifecycle.
For contacts that:
-
Have yet to start, the contact will be cancelled.
-
Have started but have yet to finish, the contact will be stopped.
87 |
# File 'sig/client.rbs', line 87
def cancel_contact: (
|
#create_config(params = {}) ⇒ Types::ConfigIdResponse
Creates a Config with the specified configData parameters.
Only one type of configData can be specified.
99 |
# File 'sig/client.rbs', line 99
def create_config: (
|
#create_dataflow_endpoint_group(params = {}) ⇒ Types::DataflowEndpointGroupIdResponse
Creates a DataflowEndpoint group containing the specified list of DataflowEndpoint objects.
The name field in each endpoint is used in your mission profile DataflowEndpointConfig to specify which endpoints to use during a
contact.
When a contact uses multiple DataflowEndpointConfig objects, each Config must match a DataflowEndpoint in the same group.
111 |
# File 'sig/client.rbs', line 111
def create_dataflow_endpoint_group: (
|
#create_dataflow_endpoint_group_v2(params = {}) ⇒ Types::CreateDataflowEndpointGroupV2Response
Creates a DataflowEndpoint group containing the specified list of
Ground Station Agent based endpoints.
The name field in each endpoint is used in your mission profile DataflowEndpointConfig to specify which endpoints to use during a
contact.
When a contact uses multiple DataflowEndpointConfig objects, each Config must match a DataflowEndpoint in the same group.
168 |
# File 'sig/client.rbs', line 168
def create_dataflow_endpoint_group_v2: (
|
#create_ephemeris(params = {}) ⇒ Types::EphemerisIdResponse
Create an ephemeris with your specified EphemerisData.
192 |
# File 'sig/client.rbs', line 192
def create_ephemeris: (
|
#create_mission_profile(params = {}) ⇒ Types::MissionProfileIdResponse
Creates a mission profile.
dataflowEdges is a list of lists of strings. Each lower level list
of strings has two elements: a from ARN and a to ARN.
264 |
# File 'sig/client.rbs', line 264
def create_mission_profile: (
|
#delete_config(params = {}) ⇒ Types::ConfigIdResponse
Deletes a Config.
291 |
# File 'sig/client.rbs', line 291
def delete_config: (
|
#delete_dataflow_endpoint_group(params = {}) ⇒ Types::DataflowEndpointGroupIdResponse
Deletes a dataflow endpoint group.
302 |
# File 'sig/client.rbs', line 302
def delete_dataflow_endpoint_group: (
|
#delete_ephemeris(params = {}) ⇒ Types::EphemerisIdResponse
Delete an ephemeris.
312 |
# File 'sig/client.rbs', line 312
def delete_ephemeris: (
|
#delete_mission_profile(params = {}) ⇒ Types::MissionProfileIdResponse
Deletes a mission profile.
322 |
# File 'sig/client.rbs', line 322
def delete_mission_profile: (
|
#describe_contact(params = {}) ⇒ Types::DescribeContactResponse
Describes an existing contact.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* contact_scheduled
350 |
# File 'sig/client.rbs', line 350
def describe_contact: (
|
#describe_contact_version(params = {}) ⇒ Types::DescribeContactVersionResponse
Describes a specific version of a contact.
The following waiters are defined for this operation (see #wait_until for detailed usage):
* contact_updated
378 |
# File 'sig/client.rbs', line 378
def describe_contact_version: (
|
#describe_ephemeris(params = {}) ⇒ Types::DescribeEphemerisResponse
Retrieve information about an existing ephemeris.
399 |
# File 'sig/client.rbs', line 399
def describe_ephemeris: (
|
#get_agent_configuration(params = {}) ⇒ Types::GetAgentConfigurationResponse
Gets the latest configuration information for a registered agent.
410 |
# File 'sig/client.rbs', line 410
def get_agent_configuration: (
|
#get_agent_task_response_url(params = {}) ⇒ Types::GetAgentTaskResponseUrlResponse
Gets a presigned URL for uploading agent task response logs.
422 |
# File 'sig/client.rbs', line 422
def get_agent_task_response_url: (
|
#get_config(params = {}) ⇒ Types::GetConfigResponse
Returns Config information.
Only one Config response can be returned.
438 |
# File 'sig/client.rbs', line 438
def get_config: (
|
#get_dataflow_endpoint_group(params = {}) ⇒ Types::GetDataflowEndpointGroupResponse
Returns the dataflow endpoint group.
454 |
# File 'sig/client.rbs', line 454
def get_dataflow_endpoint_group: (
|
#get_minute_usage(params = {}) ⇒ Types::GetMinuteUsageResponse
Returns the number of reserved minutes used by account.
468 |
# File 'sig/client.rbs', line 468
def get_minute_usage: (
|
#get_mission_profile(params = {}) ⇒ Types::GetMissionProfileResponse
Returns a mission profile.
491 |
# File 'sig/client.rbs', line 491
def get_mission_profile: (
|
#get_satellite(params = {}) ⇒ Types::GetSatelliteResponse
Returns a satellite.
505 |
# File 'sig/client.rbs', line 505
def get_satellite: (
|
#list_antennas(params = {}) ⇒ Types::ListAntennasResponse
Returns a list of antennas at a specified ground station.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
516 |
# File 'sig/client.rbs', line 516
def list_antennas: (
|
#list_configs(params = {}) ⇒ Types::ListConfigsResponse
Returns a list of Config objects.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
529 |
# File 'sig/client.rbs', line 529
def list_configs: (
|
#list_contact_versions(params = {}) ⇒ Types::ListContactVersionsResponse
Returns a list of versions for a specified contact.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
541 |
# File 'sig/client.rbs', line 541
def list_contact_versions: (
|
#list_contacts(params = {}) ⇒ Types::ListContactsResponse
Returns a list of contacts.
If statusList contains AVAILABLE, the request must include groundStation, missionprofileArn, and satelliteArn.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
554 |
# File 'sig/client.rbs', line 554
def list_contacts: (
|
#list_dataflow_endpoint_groups(params = {}) ⇒ Types::ListDataflowEndpointGroupsResponse
Returns a list of DataflowEndpoint groups.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
577 |
# File 'sig/client.rbs', line 577
def list_dataflow_endpoint_groups: (
|
#list_ephemerides(params = {}) ⇒ Types::ListEphemeridesResponse
List your existing ephemerides.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
589 |
# File 'sig/client.rbs', line 589
def list_ephemerides: (
|
#list_ground_station_reservations(params = {}) ⇒ Types::ListGroundStationReservationsResponse
Returns a list of reservations for a specified ground station.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
606 |
# File 'sig/client.rbs', line 606
def list_ground_station_reservations: (
|
#list_ground_stations(params = {}) ⇒ Types::ListGroundStationsResponse
Returns a list of ground stations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
622 |
# File 'sig/client.rbs', line 622
def list_ground_stations: (
|
#list_mission_profiles(params = {}) ⇒ Types::ListMissionProfilesResponse
Returns a list of mission profiles.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
635 |
# File 'sig/client.rbs', line 635
def list_mission_profiles: (
|
#list_satellites(params = {}) ⇒ Types::ListSatellitesResponse
Returns a list of satellites.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
647 |
# File 'sig/client.rbs', line 647
def list_satellites: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns a list of tags for a specified resource.
658 |
# File 'sig/client.rbs', line 658
def list_tags_for_resource: (
|
#register_agent(params = {}) ⇒ Types::RegisterAgentResponse
Registers a new agent with AWS Ground Station.
668 |
# File 'sig/client.rbs', line 668
def register_agent: (
|
#reserve_contact(params = {}) ⇒ Types::ContactIdResponse
Reserves a contact using specified parameters.
697 |
# File 'sig/client.rbs', line 697
def reserve_contact: (
|
#tag_resource(params = {}) ⇒ Struct
Assigns a tag to a resource.
712 |
# File 'sig/client.rbs', line 712
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Deassigns a resource tag.
722 |
# File 'sig/client.rbs', line 722
def untag_resource: (
|
#update_agent_status(params = {}) ⇒ Types::UpdateAgentStatusResponse
Update the status of the agent.
733 |
# File 'sig/client.rbs', line 733
def update_agent_status: (
|
#update_config(params = {}) ⇒ Types::ConfigIdResponse
Updates the Config used when scheduling contacts.
Updating a Config will not update the execution parameters for
existing future contacts scheduled with this Config.
761 |
# File 'sig/client.rbs', line 761
def update_config: (
|
#update_contact(params = {}) ⇒ Types::UpdateContactResponse
Updates a specific contact.
775 |
# File 'sig/client.rbs', line 775
def update_contact: (
|
#update_ephemeris(params = {}) ⇒ Types::EphemerisIdResponse
Update an existing ephemeris.
788 |
# File 'sig/client.rbs', line 788
def update_ephemeris: (
|
#update_mission_profile(params = {}) ⇒ Types::MissionProfileIdResponse
Updates a mission profile.
Updating a mission profile will not update the execution parameters for existing future contacts.
801 |
# File 'sig/client.rbs', line 801
def update_mission_profile: (
|
#wait_until(waiter_name, params = {}, options = {}) {|w.waiter| ... } ⇒ Boolean
Polls an API operation until a resource enters a desired state.
Basic Usage
A waiter will call an API operation until:
- It is successful
- It enters a terminal state
- It makes the maximum number of attempts
In between attempts, the waiter will sleep.
# polls in a loop, sleeping between attempts
client.wait_until(waiter_name, params)
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. You can pass configuration as the final arguments hash.
# poll for ~25 seconds
client.wait_until(waiter_name, params, {
max_attempts: 5,
delay: 5,
})
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
client.wait_until(waiter_name, params, {
# disable max attempts
max_attempts: nil,
# poll for 1 hour, instead of a number of attempts
before_wait: -> (attempts, response) do
throw :failure if Time.now - started_at > 3600
end
})
Handling Errors
When a waiter is unsuccessful, it will raise an error. All of the failure errors extend from Waiters::Errors::WaiterFailed.
begin
client.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
Valid Waiters
The following table lists the valid waiter names, the operations they call,
and the default :delay and :max_attempts values.
| waiter_name | params | :delay | :max_attempts |
|---|---|---|---|
| contact_scheduled | #describe_contact | 5 | 180 |
| contact_updated | #describe_contact_version | 5 | 180 |
822 |
# File 'sig/client.rbs', line 822
def wait_until: (:contact_scheduled waiter_name,
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3266 3267 3268 |
# File 'lib/aws-sdk-groundstation/client.rb', line 3266 def waiter_names waiters.keys end |