Module: Aws::GroundStation::Types
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Defined Under Namespace
Classes: AgentDetails, AggregateStatus, AntennaDemodDecodeDetails, AntennaDownlinkConfig, AntennaDownlinkDemodDecodeConfig, AntennaListItem, AntennaUplinkConfig, AwsGroundStationAgentEndpoint, AzElEphemeris, AzElEphemerisFilter, AzElProgramTrackSettings, AzElSegment, AzElSegments, AzElSegmentsData, CancelContactRequest, ComponentStatusData, ComponentVersion, ConfigDetails, ConfigIdResponse, ConfigListItem, ConfigTypeData, ConnectionDetails, ContactData, ContactIdResponse, ContactReservationDetails, ContactVersion, CreateConfigRequest, CreateDataflowEndpointGroupRequest, CreateDataflowEndpointGroupV2Request, CreateDataflowEndpointGroupV2Response, CreateEndpointDetails, CreateEphemerisRequest, CreateMissionProfileRequest, DataflowDetail, DataflowEndpoint, DataflowEndpointConfig, DataflowEndpointGroupIdResponse, DataflowEndpointListItem, DecodeConfig, DeleteConfigRequest, DeleteDataflowEndpointGroupRequest, DeleteEphemerisRequest, DeleteMissionProfileRequest, DemodulationConfig, DependencyException, DescribeContactRequest, DescribeContactResponse, DescribeContactVersionRequest, DescribeContactVersionResponse, DescribeEphemerisRequest, DescribeEphemerisResponse, Destination, DiscoveryData, DownlinkAwsGroundStationAgentEndpoint, DownlinkAwsGroundStationAgentEndpointDetails, DownlinkConnectionDetails, DownlinkDataflowDetails, Eirp, Elevation, EndpointDetails, EphemerisData, EphemerisDescription, EphemerisErrorReason, EphemerisFilter, EphemerisIdResponse, EphemerisItem, EphemerisMetaData, EphemerisResponseData, EphemerisTypeDescription, Frequency, FrequencyBandwidth, GetAgentConfigurationRequest, GetAgentConfigurationResponse, GetAgentTaskResponseUrlRequest, GetAgentTaskResponseUrlResponse, GetConfigRequest, GetConfigResponse, GetDataflowEndpointGroupRequest, GetDataflowEndpointGroupResponse, GetMinuteUsageRequest, GetMinuteUsageResponse, GetMissionProfileRequest, GetMissionProfileResponse, GetSatelliteRequest, GetSatelliteResponse, GroundStationData, GroundStationReservationListItem, ISO8601TimeRange, IntegerRange, InvalidParameterException, KinesisDataStreamData, KmsKey, ListAntennasRequest, ListAntennasResponse, ListConfigsRequest, ListConfigsResponse, ListContactVersionsRequest, ListContactVersionsResponse, ListContactsRequest, ListContactsResponse, ListDataflowEndpointGroupsRequest, ListDataflowEndpointGroupsResponse, ListEphemeridesRequest, ListEphemeridesResponse, ListGroundStationReservationsRequest, ListGroundStationReservationsResponse, ListGroundStationsRequest, ListGroundStationsResponse, ListMissionProfilesRequest, ListMissionProfilesResponse, ListSatellitesRequest, ListSatellitesResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, MaintenanceReservationDetails, MissionProfileIdResponse, MissionProfileListItem, OEMEphemeris, OemProgramTrackSettings, ProgramTrackSettings, RangedConnectionDetails, RangedSocketAddress, RegisterAgentRequest, RegisterAgentResponse, ReservationDetails, ReserveContactRequest, ResourceInUseException, ResourceLimitExceededException, ResourceNotFoundException, S3Object, S3RecordingConfig, S3RecordingDetails, SatelliteListItem, SecurityDetails, ServiceQuotaExceededException, SocketAddress, Source, SpectrumConfig, TLEData, TLEEphemeris, TagResourceRequest, TagResourceResponse, TelemetrySinkConfig, TelemetrySinkData, TimeAzEl, TimeRange, TleProgramTrackSettings, TrackingConfig, TrackingOverrides, UntagResourceRequest, UntagResourceResponse, UpdateAgentStatusRequest, UpdateAgentStatusResponse, UpdateConfigRequest, UpdateContactRequest, UpdateContactResponse, UpdateEphemerisRequest, UpdateMissionProfileRequest, UplinkAwsGroundStationAgentEndpoint, UplinkAwsGroundStationAgentEndpointDetails, UplinkConnectionDetails, UplinkDataflowDetails, UplinkEchoConfig, UplinkSpectrumConfig
Instance Attribute Summary collapse
-
#agent_connection_details ⇒ Types::UplinkConnectionDetails
Uplink connection details for customer to Agent and Agent to Ground Station.
-
#antenna_demod_decode_details ⇒ Types::AntennaDemodDecodeDetails
Details for antenna demod decode ‘Config` in a contact.
-
#antenna_downlink_config ⇒ Types::AntennaDownlinkConfig
Information about how AWS Ground Station should configure an antenna for downlink during a contact.
-
#antenna_downlink_demod_decode_config ⇒ Types::AntennaDownlinkDemodDecodeConfig
Information about how AWS Ground Station should configure an antenna for downlink demod decode during a contact.
-
#antenna_uplink_config ⇒ Types::AntennaUplinkConfig
Information about how AWS Ground Station should configure an antenna for uplink during a contact.
-
#az_el ⇒ Types::AzElProgramTrackSettings
Program track settings for AzElEphemeris.
-
#az_el_data ⇒ Types::AzElSegments
Azimuth elevation segment data provided directly in the request.
-
#contact ⇒ Types::ContactReservationDetails
Details of a contact reservation.
-
#dataflow_endpoint_config ⇒ Types::DataflowEndpointConfig
Information about the dataflow endpoint ‘Config`.
-
#downlink_aws_ground_station_agent_endpoint ⇒ Types::DownlinkAwsGroundStationAgentEndpoint
Definition for a downlink agent endpoint.
-
#endpoint_details ⇒ Types::EndpointDetails
Information about the endpoint details.
-
#kinesis_data_stream_data ⇒ Types::KinesisDataStreamData
Information about a telemetry sink of type ‘KINESIS_DATA_STREAM`.
-
#kms_alias_arn ⇒ String
KMS Alias Arn.
-
#kms_alias_name ⇒ String
KMS Alias Name.
-
#kms_key_arn ⇒ String
KMS Key Arn.
-
#maintenance ⇒ Types::MaintenanceReservationDetails
Details of a maintenance reservation.
-
#oem ⇒ Types::OemProgramTrackSettings
Program track settings for OEMEphemeris.
-
#s3_object ⇒ Types::S3Object
The Amazon S3 object containing azimuth elevation segment data.
-
#s3_recording_config ⇒ Types::S3RecordingConfig
Information about an S3 recording ‘Config`.
-
#s3_recording_details ⇒ Types::S3RecordingDetails
Details for an S3 recording ‘Config` in a contact.
-
#telemetry_sink_config ⇒ Types::TelemetrySinkConfig
Information about a telemetry sink ‘Config`.
-
#tle ⇒ Types::TleProgramTrackSettings
Program track settings for TLEEphemeris.
-
#tracking_config ⇒ Types::TrackingConfig
Object that determines whether tracking should be used during a contact executed with this ‘Config` in the mission profile.
-
#uplink_aws_ground_station_agent_endpoint ⇒ Types::UplinkAwsGroundStationAgentEndpoint
Definition for an uplink agent endpoint.
-
#uplink_echo_config ⇒ Types::UplinkEchoConfig
Information about an uplink echo ‘Config`.
Instance Attribute Details
#agent_connection_details ⇒ Types::UplinkConnectionDetails
Uplink connection details for customer to Agent and Agent to Ground Station
1837 1838 1839 1840 1841 1842 1843 1844 1845 1846 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1837 class DownlinkDataflowDetails < Struct.new( :agent_connection_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AgentConnectionDetails < DownlinkDataflowDetails; end class Unknown < DownlinkDataflowDetails; end end |
#antenna_demod_decode_details ⇒ Types::AntennaDemodDecodeDetails
Details for antenna demod decode ‘Config` in a contact.
490 491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-groundstation/types.rb', line 490 class ConfigDetails < Struct.new( :endpoint_details, :antenna_demod_decode_details, :s3_recording_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EndpointDetails < ConfigDetails; end class AntennaDemodDecodeDetails < ConfigDetails; end class S3RecordingDetails < ConfigDetails; end class Unknown < ConfigDetails; end end |
#antenna_downlink_config ⇒ Types::AntennaDownlinkConfig
Information about how AWS Ground Station should configure an antenna for downlink during a contact.
608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/aws-sdk-groundstation/types.rb', line 608 class ConfigTypeData < Struct.new( :antenna_downlink_config, :tracking_config, :dataflow_endpoint_config, :antenna_downlink_demod_decode_config, :antenna_uplink_config, :uplink_echo_config, :s3_recording_config, :telemetry_sink_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AntennaDownlinkConfig < ConfigTypeData; end class TrackingConfig < ConfigTypeData; end class DataflowEndpointConfig < ConfigTypeData; end class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end class AntennaUplinkConfig < ConfigTypeData; end class UplinkEchoConfig < ConfigTypeData; end class S3RecordingConfig < ConfigTypeData; end class TelemetrySinkConfig < ConfigTypeData; end class Unknown < ConfigTypeData; end end |
#antenna_downlink_demod_decode_config ⇒ Types::AntennaDownlinkDemodDecodeConfig
Information about how AWS Ground Station should configure an antenna for downlink demod decode during a contact.
608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/aws-sdk-groundstation/types.rb', line 608 class ConfigTypeData < Struct.new( :antenna_downlink_config, :tracking_config, :dataflow_endpoint_config, :antenna_downlink_demod_decode_config, :antenna_uplink_config, :uplink_echo_config, :s3_recording_config, :telemetry_sink_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AntennaDownlinkConfig < ConfigTypeData; end class TrackingConfig < ConfigTypeData; end class DataflowEndpointConfig < ConfigTypeData; end class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end class AntennaUplinkConfig < ConfigTypeData; end class UplinkEchoConfig < ConfigTypeData; end class S3RecordingConfig < ConfigTypeData; end class TelemetrySinkConfig < ConfigTypeData; end class Unknown < ConfigTypeData; end end |
#antenna_uplink_config ⇒ Types::AntennaUplinkConfig
Information about how AWS Ground Station should configure an antenna for uplink during a contact.
608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/aws-sdk-groundstation/types.rb', line 608 class ConfigTypeData < Struct.new( :antenna_downlink_config, :tracking_config, :dataflow_endpoint_config, :antenna_downlink_demod_decode_config, :antenna_uplink_config, :uplink_echo_config, :s3_recording_config, :telemetry_sink_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AntennaDownlinkConfig < ConfigTypeData; end class TrackingConfig < ConfigTypeData; end class DataflowEndpointConfig < ConfigTypeData; end class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end class AntennaUplinkConfig < ConfigTypeData; end class UplinkEchoConfig < ConfigTypeData; end class S3RecordingConfig < ConfigTypeData; end class TelemetrySinkConfig < ConfigTypeData; end class Unknown < ConfigTypeData; end end |
#az_el ⇒ Types::AzElProgramTrackSettings
Program track settings for AzElEphemeris.
1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1992 class EphemerisData < Struct.new( :tle, :oem, :az_el, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tle < EphemerisData; end class Oem < EphemerisData; end class AzEl < EphemerisData; end class Unknown < EphemerisData; end end |
#az_el_data ⇒ Types::AzElSegments
Azimuth elevation segment data provided directly in the request.
Use this option for smaller datasets or when Amazon S3 access is not available.
382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/aws-sdk-groundstation/types.rb', line 382 class AzElSegmentsData < Struct.new( :s3_object, :az_el_data, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3Object < AzElSegmentsData; end class AzElData < AzElSegmentsData; end class Unknown < AzElSegmentsData; end end |
#contact ⇒ Types::ContactReservationDetails
Details of a contact reservation.
3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3584 class ReservationDetails < Struct.new( :maintenance, :contact, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Maintenance < ReservationDetails; end class Contact < ReservationDetails; end class Unknown < ReservationDetails; end end |
#dataflow_endpoint_config ⇒ Types::DataflowEndpointConfig
Information about the dataflow endpoint ‘Config`.
608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/aws-sdk-groundstation/types.rb', line 608 class ConfigTypeData < Struct.new( :antenna_downlink_config, :tracking_config, :dataflow_endpoint_config, :antenna_downlink_demod_decode_config, :antenna_uplink_config, :uplink_echo_config, :s3_recording_config, :telemetry_sink_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AntennaDownlinkConfig < ConfigTypeData; end class TrackingConfig < ConfigTypeData; end class DataflowEndpointConfig < ConfigTypeData; end class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end class AntennaUplinkConfig < ConfigTypeData; end class UplinkEchoConfig < ConfigTypeData; end class S3RecordingConfig < ConfigTypeData; end class TelemetrySinkConfig < ConfigTypeData; end class Unknown < ConfigTypeData; end end |
#downlink_aws_ground_station_agent_endpoint ⇒ Types::DownlinkAwsGroundStationAgentEndpoint
Definition for a downlink agent endpoint
997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-groundstation/types.rb', line 997 class CreateEndpointDetails < Struct.new( :uplink_aws_ground_station_agent_endpoint, :downlink_aws_ground_station_agent_endpoint, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class UplinkAwsGroundStationAgentEndpoint < CreateEndpointDetails; end class DownlinkAwsGroundStationAgentEndpoint < CreateEndpointDetails; end class Unknown < CreateEndpointDetails; end end |
#endpoint_details ⇒ Types::EndpointDetails
Information about the endpoint details.
490 491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-groundstation/types.rb', line 490 class ConfigDetails < Struct.new( :endpoint_details, :antenna_demod_decode_details, :s3_recording_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EndpointDetails < ConfigDetails; end class AntennaDemodDecodeDetails < ConfigDetails; end class S3RecordingDetails < ConfigDetails; end class Unknown < ConfigDetails; end end |
#kinesis_data_stream_data ⇒ Types::KinesisDataStreamData
Information about a telemetry sink of type ‘KINESIS_DATA_STREAM`.
4028 4029 4030 4031 4032 4033 4034 4035 4036 4037 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4028 class TelemetrySinkData < Struct.new( :kinesis_data_stream_data, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class KinesisDataStreamData < TelemetrySinkData; end class Unknown < TelemetrySinkData; end end |
#kms_alias_arn ⇒ String
KMS Alias Arn.
2832 2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2832 class KmsKey < Struct.new( :kms_key_arn, :kms_alias_arn, :kms_alias_name, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class KmsKeyArn < KmsKey; end class KmsAliasArn < KmsKey; end class KmsAliasName < KmsKey; end class Unknown < KmsKey; end end |
#kms_alias_name ⇒ String
KMS Alias Name.
2832 2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2832 class KmsKey < Struct.new( :kms_key_arn, :kms_alias_arn, :kms_alias_name, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class KmsKeyArn < KmsKey; end class KmsAliasArn < KmsKey; end class KmsAliasName < KmsKey; end class Unknown < KmsKey; end end |
#kms_key_arn ⇒ String
KMS Key Arn.
2832 2833 2834 2835 2836 2837 2838 2839 2840 2841 2842 2843 2844 2845 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2832 class KmsKey < Struct.new( :kms_key_arn, :kms_alias_arn, :kms_alias_name, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class KmsKeyArn < KmsKey; end class KmsAliasArn < KmsKey; end class KmsAliasName < KmsKey; end class Unknown < KmsKey; end end |
#maintenance ⇒ Types::MaintenanceReservationDetails
Details of a maintenance reservation.
3584 3585 3586 3587 3588 3589 3590 3591 3592 3593 3594 3595 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3584 class ReservationDetails < Struct.new( :maintenance, :contact, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Maintenance < ReservationDetails; end class Contact < ReservationDetails; end class Unknown < ReservationDetails; end end |
#oem ⇒ Types::OemProgramTrackSettings
Program track settings for OEMEphemeris.
1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1992 class EphemerisData < Struct.new( :tle, :oem, :az_el, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tle < EphemerisData; end class Oem < EphemerisData; end class AzEl < EphemerisData; end class Unknown < EphemerisData; end end |
#s3_object ⇒ Types::S3Object
The Amazon S3 object containing azimuth elevation segment data.
The Amazon S3 object must contain JSON-formatted azimuth elevation data matching the AzElSegments structure.
382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/aws-sdk-groundstation/types.rb', line 382 class AzElSegmentsData < Struct.new( :s3_object, :az_el_data, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class S3Object < AzElSegmentsData; end class AzElData < AzElSegmentsData; end class Unknown < AzElSegmentsData; end end |
#s3_recording_config ⇒ Types::S3RecordingConfig
Information about an S3 recording ‘Config`.
608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/aws-sdk-groundstation/types.rb', line 608 class ConfigTypeData < Struct.new( :antenna_downlink_config, :tracking_config, :dataflow_endpoint_config, :antenna_downlink_demod_decode_config, :antenna_uplink_config, :uplink_echo_config, :s3_recording_config, :telemetry_sink_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AntennaDownlinkConfig < ConfigTypeData; end class TrackingConfig < ConfigTypeData; end class DataflowEndpointConfig < ConfigTypeData; end class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end class AntennaUplinkConfig < ConfigTypeData; end class UplinkEchoConfig < ConfigTypeData; end class S3RecordingConfig < ConfigTypeData; end class TelemetrySinkConfig < ConfigTypeData; end class Unknown < ConfigTypeData; end end |
#s3_recording_details ⇒ Types::S3RecordingDetails
Details for an S3 recording ‘Config` in a contact.
490 491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/aws-sdk-groundstation/types.rb', line 490 class ConfigDetails < Struct.new( :endpoint_details, :antenna_demod_decode_details, :s3_recording_details, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class EndpointDetails < ConfigDetails; end class AntennaDemodDecodeDetails < ConfigDetails; end class S3RecordingDetails < ConfigDetails; end class Unknown < ConfigDetails; end end |
#telemetry_sink_config ⇒ Types::TelemetrySinkConfig
Information about a telemetry sink ‘Config`.
608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/aws-sdk-groundstation/types.rb', line 608 class ConfigTypeData < Struct.new( :antenna_downlink_config, :tracking_config, :dataflow_endpoint_config, :antenna_downlink_demod_decode_config, :antenna_uplink_config, :uplink_echo_config, :s3_recording_config, :telemetry_sink_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AntennaDownlinkConfig < ConfigTypeData; end class TrackingConfig < ConfigTypeData; end class DataflowEndpointConfig < ConfigTypeData; end class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end class AntennaUplinkConfig < ConfigTypeData; end class UplinkEchoConfig < ConfigTypeData; end class S3RecordingConfig < ConfigTypeData; end class TelemetrySinkConfig < ConfigTypeData; end class Unknown < ConfigTypeData; end end |
#tle ⇒ Types::TleProgramTrackSettings
Program track settings for TLEEphemeris.
1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1992 class EphemerisData < Struct.new( :tle, :oem, :az_el, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tle < EphemerisData; end class Oem < EphemerisData; end class AzEl < EphemerisData; end class Unknown < EphemerisData; end end |
#tracking_config ⇒ Types::TrackingConfig
Object that determines whether tracking should be used during a contact executed with this ‘Config` in the mission profile.
608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/aws-sdk-groundstation/types.rb', line 608 class ConfigTypeData < Struct.new( :antenna_downlink_config, :tracking_config, :dataflow_endpoint_config, :antenna_downlink_demod_decode_config, :antenna_uplink_config, :uplink_echo_config, :s3_recording_config, :telemetry_sink_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AntennaDownlinkConfig < ConfigTypeData; end class TrackingConfig < ConfigTypeData; end class DataflowEndpointConfig < ConfigTypeData; end class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end class AntennaUplinkConfig < ConfigTypeData; end class UplinkEchoConfig < ConfigTypeData; end class S3RecordingConfig < ConfigTypeData; end class TelemetrySinkConfig < ConfigTypeData; end class Unknown < ConfigTypeData; end end |
#uplink_aws_ground_station_agent_endpoint ⇒ Types::UplinkAwsGroundStationAgentEndpoint
Definition for an uplink agent endpoint
997 998 999 1000 1001 1002 1003 1004 1005 1006 1007 1008 |
# File 'lib/aws-sdk-groundstation/types.rb', line 997 class CreateEndpointDetails < Struct.new( :uplink_aws_ground_station_agent_endpoint, :downlink_aws_ground_station_agent_endpoint, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class UplinkAwsGroundStationAgentEndpoint < CreateEndpointDetails; end class DownlinkAwsGroundStationAgentEndpoint < CreateEndpointDetails; end class Unknown < CreateEndpointDetails; end end |
#uplink_echo_config ⇒ Types::UplinkEchoConfig
Information about an uplink echo ‘Config`.
Parameters from the ‘AntennaUplinkConfig`, corresponding to the specified ` AntennaUplinkConfigArn`, are used when this `UplinkEchoConfig` is used in a contact.
608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/aws-sdk-groundstation/types.rb', line 608 class ConfigTypeData < Struct.new( :antenna_downlink_config, :tracking_config, :dataflow_endpoint_config, :antenna_downlink_demod_decode_config, :antenna_uplink_config, :uplink_echo_config, :s3_recording_config, :telemetry_sink_config, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class AntennaDownlinkConfig < ConfigTypeData; end class TrackingConfig < ConfigTypeData; end class DataflowEndpointConfig < ConfigTypeData; end class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end class AntennaUplinkConfig < ConfigTypeData; end class UplinkEchoConfig < ConfigTypeData; end class S3RecordingConfig < ConfigTypeData; end class TelemetrySinkConfig < ConfigTypeData; end class Unknown < ConfigTypeData; end end |