Class: Aws::GroundStation::Types::AntennaListItem
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::AntennaListItem
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
An antenna at a ground station.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#antenna_name ⇒ String
Name of the antenna.
-
#ground_station_name ⇒ String
Name of the ground station the antenna is associated with.
-
#region ⇒ String
Region of the antenna.
Instance Attribute Details
#antenna_name ⇒ String
Name of the antenna.
147 148 149 150 151 152 153 |
# File 'lib/aws-sdk-groundstation/types.rb', line 147 class AntennaListItem < Struct.new( :ground_station_name, :antenna_name, :region) SENSITIVE = [] include Aws::Structure end |
#ground_station_name ⇒ String
Name of the ground station the antenna is associated with.
147 148 149 150 151 152 153 |
# File 'lib/aws-sdk-groundstation/types.rb', line 147 class AntennaListItem < Struct.new( :ground_station_name, :antenna_name, :region) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
Region of the antenna.
147 148 149 150 151 152 153 |
# File 'lib/aws-sdk-groundstation/types.rb', line 147 class AntennaListItem < Struct.new( :ground_station_name, :antenna_name, :region) SENSITIVE = [] include Aws::Structure end |