Class: Aws::GroundStation::Types::ContactData
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::ContactData
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Data describing a contact.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_id ⇒ String
UUID of a contact.
-
#contact_status ⇒ String
Status of a contact.
-
#end_time ⇒ Time
End time of a contact in UTC.
-
#ephemeris ⇒ Types::EphemerisResponseData
The ephemeris that determines antenna pointing for the contact.
-
#error_message ⇒ String
Error message of a contact.
-
#ground_station ⇒ String
Name of a ground station.
-
#maximum_elevation ⇒ Types::Elevation
Maximum elevation angle of a contact.
-
#mission_profile_arn ⇒ String
ARN of a mission profile.
-
#post_pass_end_time ⇒ Time
End time in UTC of the post-pass period, at which you receive a CloudWatch event indicating the pass has finished.
-
#pre_pass_start_time ⇒ Time
Start time in UTC of the pre-pass period, at which you receive a CloudWatch event indicating an upcoming pass.
-
#region ⇒ String
Region of a contact.
-
#satellite_arn ⇒ String
ARN of a satellite.
-
#start_time ⇒ Time
Start time of a contact in UTC.
-
#tags ⇒ Hash<String,String>
Tags assigned to a contact.
-
#version ⇒ Types::ContactVersion
Version information for a contact.
-
#visibility_end_time ⇒ Time
Projected time in UTC your satellite will set below the [receive mask].
-
#visibility_start_time ⇒ Time
Projected time in UTC your satellite will rise above the [receive mask].
Instance Attribute Details
#contact_id ⇒ String
UUID of a contact.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#contact_status ⇒ String
Status of a contact.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
End time of a contact in UTC.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#ephemeris ⇒ Types::EphemerisResponseData
The ephemeris that determines antenna pointing for the contact.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
Error message of a contact.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#ground_station ⇒ String
Name of a ground station.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#maximum_elevation ⇒ Types::Elevation
Maximum elevation angle of a contact.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#mission_profile_arn ⇒ String
ARN of a mission profile.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#post_pass_end_time ⇒ Time
End time in UTC of the post-pass period, at which you receive a CloudWatch event indicating the pass has finished.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#pre_pass_start_time ⇒ Time
Start time in UTC of the pre-pass period, at which you receive a CloudWatch event indicating an upcoming pass.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
Region of a contact.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#satellite_arn ⇒ String
ARN of a satellite.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
Start time of a contact in UTC.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags assigned to a contact.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ Types::ContactVersion
Version information for a contact.
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#visibility_end_time ⇒ Time
Projected time in UTC your satellite will set below the [receive mask]. This time is based on the satellite’s current active ephemeris for future contacts and the ephemeris that was active during contact execution for completed contacts. *This field is not present for contacts with a ‘SCHEDULING` or `SCHEDULED` status.*
[1]: docs.aws.amazon.com/ground-station/latest/ug/site-masks.html
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |
#visibility_start_time ⇒ Time
Projected time in UTC your satellite will rise above the [receive mask]. This time is based on the satellite’s current active ephemeris for future contacts and the ephemeris that was active during contact execution for completed contacts. *This field is not present for contacts with a ‘SCHEDULING` or `SCHEDULED` status.*
[1]: docs.aws.amazon.com/ground-station/latest/ug/site-masks.html
743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 |
# File 'lib/aws-sdk-groundstation/types.rb', line 743 class ContactData < Struct.new( :contact_id, :mission_profile_arn, :satellite_arn, :start_time, :end_time, :pre_pass_start_time, :post_pass_end_time, :ground_station, :contact_status, :error_message, :maximum_elevation, :region, :tags, :visibility_start_time, :visibility_end_time, :ephemeris, :version) SENSITIVE = [] include Aws::Structure end |