Class: Aws::GroundStation::Types::ContactVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::ContactVersion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Version information for a contact.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#activated ⇒ Time
Time the contact version was activated in UTC.
-
#created ⇒ Time
Time the contact version was created in UTC.
-
#failure_codes ⇒ Array<String>
List of failure codes for the contact version.
-
#failure_message ⇒ String
Failure message for the contact version.
-
#last_updated ⇒ Time
Time the contact version was last updated in UTC.
-
#status ⇒ String
Status of the contact version.
-
#superseded ⇒ Time
Time the contact version was superseded in UTC.
-
#version_id ⇒ Integer
Version ID of a contact.
Instance Attribute Details
#activated ⇒ Time
Time the contact version was activated in UTC. A version is activated when it becomes the current active version of the contact.
836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/aws-sdk-groundstation/types.rb', line 836 class ContactVersion < Struct.new( :version_id, :created, :activated, :superseded, :last_updated, :status, :failure_codes, :failure_message) SENSITIVE = [] include Aws::Structure end |
#created ⇒ Time
Time the contact version was created in UTC.
836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/aws-sdk-groundstation/types.rb', line 836 class ContactVersion < Struct.new( :version_id, :created, :activated, :superseded, :last_updated, :status, :failure_codes, :failure_message) SENSITIVE = [] include Aws::Structure end |
#failure_codes ⇒ Array<String>
List of failure codes for the contact version.
836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/aws-sdk-groundstation/types.rb', line 836 class ContactVersion < Struct.new( :version_id, :created, :activated, :superseded, :last_updated, :status, :failure_codes, :failure_message) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
Failure message for the contact version.
836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/aws-sdk-groundstation/types.rb', line 836 class ContactVersion < Struct.new( :version_id, :created, :activated, :superseded, :last_updated, :status, :failure_codes, :failure_message) SENSITIVE = [] include Aws::Structure end |
#last_updated ⇒ Time
Time the contact version was last updated in UTC.
836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/aws-sdk-groundstation/types.rb', line 836 class ContactVersion < Struct.new( :version_id, :created, :activated, :superseded, :last_updated, :status, :failure_codes, :failure_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Status of the contact version.
836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/aws-sdk-groundstation/types.rb', line 836 class ContactVersion < Struct.new( :version_id, :created, :activated, :superseded, :last_updated, :status, :failure_codes, :failure_message) SENSITIVE = [] include Aws::Structure end |
#superseded ⇒ Time
Time the contact version was superseded in UTC. A version is superseded when a newer version becomes active.
836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/aws-sdk-groundstation/types.rb', line 836 class ContactVersion < Struct.new( :version_id, :created, :activated, :superseded, :last_updated, :status, :failure_codes, :failure_message) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ Integer
Version ID of a contact.
836 837 838 839 840 841 842 843 844 845 846 847 |
# File 'lib/aws-sdk-groundstation/types.rb', line 836 class ContactVersion < Struct.new( :version_id, :created, :activated, :superseded, :last_updated, :status, :failure_codes, :failure_message) SENSITIVE = [] include Aws::Structure end |