Class: Aws::GroundStation::Types::CreateDataflowEndpointGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_post_pass_duration_secondsInteger

Amount of time, in seconds, after a contact ends that the Ground Station Dataflow Endpoint Group will be in a POSTPASS state. A

Ground Station Dataflow Endpoint Group State Change event][1

will

be emitted when the Dataflow Endpoint Group enters and exits the POSTPASS state.

[1]: docs.aws.amazon.com/ground-station/latest/ug/monitoring.automating-events.html



810
811
812
813
814
815
816
817
# File 'lib/aws-sdk-groundstation/types.rb', line 810

class CreateDataflowEndpointGroupRequest < Struct.new(
  :endpoint_details,
  :tags,
  :contact_pre_pass_duration_seconds,
  :contact_post_pass_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#contact_pre_pass_duration_secondsInteger

Amount of time, in seconds, before a contact starts that the Ground Station Dataflow Endpoint Group will be in a PREPASS state. A

Ground Station Dataflow Endpoint Group State Change event][1

will

be emitted when the Dataflow Endpoint Group enters and exits the PREPASS state.

[1]: docs.aws.amazon.com/ground-station/latest/ug/monitoring.automating-events.html



810
811
812
813
814
815
816
817
# File 'lib/aws-sdk-groundstation/types.rb', line 810

class CreateDataflowEndpointGroupRequest < Struct.new(
  :endpoint_details,
  :tags,
  :contact_pre_pass_duration_seconds,
  :contact_post_pass_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_detailsArray<Types::EndpointDetails>

Endpoint details of each endpoint in the dataflow endpoint group. All dataflow endpoints within a single dataflow endpoint group must be of the same type. You cannot mix [ AWS Ground Station Agent endpoints] with [Dataflow endpoints] in the same group. If your use case requires both types of endpoints, you must create separate dataflow endpoint groups for each type.

[1]: docs.aws.amazon.com/ground-station/latest/APIReference/API_AwsGroundStationAgentEndpoint.html [2]: docs.aws.amazon.com/ground-station/latest/APIReference/API_DataflowEndpoint.html



810
811
812
813
814
815
816
817
# File 'lib/aws-sdk-groundstation/types.rb', line 810

class CreateDataflowEndpointGroupRequest < Struct.new(
  :endpoint_details,
  :tags,
  :contact_pre_pass_duration_seconds,
  :contact_post_pass_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Tags of a dataflow endpoint group.



810
811
812
813
814
815
816
817
# File 'lib/aws-sdk-groundstation/types.rb', line 810

class CreateDataflowEndpointGroupRequest < Struct.new(
  :endpoint_details,
  :tags,
  :contact_pre_pass_duration_seconds,
  :contact_post_pass_duration_seconds)
  SENSITIVE = []
  include Aws::Structure
end