Class: Aws::GroundStation::Types::CreateMissionProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::CreateMissionProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Input for the ‘CreateMissionProfile` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_post_pass_duration_seconds ⇒ Integer
Amount of time after a contact ends that you’d like to receive a Ground Station Contact State Change event indicating the pass has finished.
-
#contact_pre_pass_duration_seconds ⇒ Integer
Amount of time prior to contact start you’d like to receive a Ground Station Contact State Change event indicating an upcoming pass.
-
#dataflow_edges ⇒ Array<Array<String>>
A list of lists of ARNs.
-
#minimum_viable_contact_duration_seconds ⇒ Integer
Smallest amount of time in seconds that you’d like to see for an available contact.
-
#name ⇒ String
Name of a mission profile.
-
#streams_kms_key ⇒ Types::KmsKey
KMS key to use for encrypting streams.
-
#streams_kms_role ⇒ String
Role to use for encrypting streams with KMS key.
-
#tags ⇒ Hash<String,String>
Tags assigned to a mission profile.
-
#telemetry_sink_config_arn ⇒ String
ARN of a telemetry sink ‘Config`.
-
#tracking_config_arn ⇒ String
ARN of a tracking ‘Config`.
Instance Attribute Details
#contact_post_pass_duration_seconds ⇒ Integer
Amount of time after a contact ends that you’d like to receive a Ground Station Contact State Change event indicating the pass has finished.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1115 class CreateMissionProfileRequest < Struct.new( :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#contact_pre_pass_duration_seconds ⇒ Integer
Amount of time prior to contact start you’d like to receive a Ground Station Contact State Change event indicating an upcoming pass.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1115 class CreateMissionProfileRequest < Struct.new( :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#dataflow_edges ⇒ Array<Array<String>>
A list of lists of ARNs. Each list of ARNs is an edge, with a from ‘ Config` and a to `Config`.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1115 class CreateMissionProfileRequest < Struct.new( :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#minimum_viable_contact_duration_seconds ⇒ Integer
Smallest amount of time in seconds that you’d like to see for an available contact. AWS Ground Station will not present you with contacts shorter than this duration.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1115 class CreateMissionProfileRequest < Struct.new( :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of a mission profile.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1115 class CreateMissionProfileRequest < Struct.new( :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#streams_kms_key ⇒ Types::KmsKey
KMS key to use for encrypting streams.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1115 class CreateMissionProfileRequest < Struct.new( :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#streams_kms_role ⇒ String
Role to use for encrypting streams with KMS key.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1115 class CreateMissionProfileRequest < Struct.new( :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags assigned to a mission profile.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1115 class CreateMissionProfileRequest < Struct.new( :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#telemetry_sink_config_arn ⇒ String
ARN of a telemetry sink ‘Config`.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1115 class CreateMissionProfileRequest < Struct.new( :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#tracking_config_arn ⇒ String
ARN of a tracking ‘Config`.
1115 1116 1117 1118 1119 1120 1121 1122 1123 1124 1125 1126 1127 1128 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1115 class CreateMissionProfileRequest < Struct.new( :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |