Class: Aws::GroundStation::Types::DescribeContactResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Output for the DescribeContact operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_id ⇒ String

UUID of a contact.

Returns:

  • (String)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#contact_status ⇒ String

Status of a contact.

Returns:

  • (String)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#dataflow_list ⇒ Array<Types::DataflowDetail>

List describing source and destination details for each dataflow edge.

Returns:



1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#end_time ⇒ Time

End time of a contact in UTC.

Returns:

  • (Time)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#ephemeris ⇒ Types::EphemerisResponseData

The ephemeris that determines antenna pointing directions for the contact.



1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#error_message ⇒ String

Error message for a contact.

Returns:

  • (String)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#ground_station ⇒ String

Ground station for a contact.

Returns:

  • (String)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#maximum_elevation ⇒ Types::Elevation

Maximum elevation angle of a contact.

Returns:



1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#mission_profile_arn ⇒ String

ARN of a mission profile.

Returns:

  • (String)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#post_pass_end_time ⇒ Time

End time in UTC of the post-pass period, at which you receive a CloudWatch event indicating the pass has finished.

Returns:

  • (Time)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#pre_pass_start_time ⇒ Time

Start time in UTC of the pre-pass period, at which you receive a CloudWatch event indicating an upcoming pass.

Returns:

  • (Time)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#region ⇒ String

Region where the ReserveContact API was called to schedule this contact.

Returns:

  • (String)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#satellite_arn ⇒ String

ARN of a satellite.

Returns:

  • (String)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ Time

Start time of a contact in UTC.

Returns:

  • (Time)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Hash<String,String>

Tags assigned to a contact.

Returns:

  • (Hash<String,String>)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#tracking_overrides ⇒ Types::TrackingOverrides

Tracking configuration overrides specified when the contact was reserved.



1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#version ⇒ Types::ContactVersion

Version information for a contact.



1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#visibility_end_time ⇒ Time

Projected time in UTC your satellite will set below the receive mask. This time is based on the satellite's current active ephemeris for future contacts and the ephemeris that was active during contact execution for completed contacts.

Returns:

  • (Time)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end

#visibility_start_time ⇒ Time

Projected time in UTC your satellite will rise above the receive mask. This time is based on the satellite's current active ephemeris for future contacts and the ephemeris that was active during contact execution for completed contacts.

Returns:

  • (Time)


1455
1456
1457
1458
1459
1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
1477
# File 'lib/aws-sdk-groundstation/types.rb', line 1455

class DescribeContactResponse < Struct.new(
  :contact_id,
  :mission_profile_arn,
  :satellite_arn,
  :start_time,
  :end_time,
  :pre_pass_start_time,
  :post_pass_end_time,
  :ground_station,
  :contact_status,
  :error_message,
  :maximum_elevation,
  :tags,
  :region,
  :dataflow_list,
  :visibility_start_time,
  :visibility_end_time,
  :tracking_overrides,
  :ephemeris,
  :version)
  SENSITIVE = []
  include Aws::Structure
end