Class: Aws::GroundStation::Types::DownlinkAwsGroundStationAgentEndpointDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::DownlinkAwsGroundStationAgentEndpointDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Details for a downlink agent endpoint
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_status ⇒ String
Status of the agent associated with the downlink dataflow endpoint.
-
#audit_results ⇒ String
Health audit results for the downlink dataflow endpoint.
-
#dataflow_details ⇒ Types::DownlinkDataflowDetails
Dataflow details for the downlink endpoint.
-
#name ⇒ String
Downlink dataflow endpoint name.
Instance Attribute Details
#agent_status ⇒ String
Status of the agent associated with the downlink dataflow endpoint
1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1523 class DownlinkAwsGroundStationAgentEndpointDetails < Struct.new( :name, :dataflow_details, :agent_status, :audit_results) SENSITIVE = [] include Aws::Structure end |
#audit_results ⇒ String
Health audit results for the downlink dataflow endpoint
1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1523 class DownlinkAwsGroundStationAgentEndpointDetails < Struct.new( :name, :dataflow_details, :agent_status, :audit_results) SENSITIVE = [] include Aws::Structure end |
#dataflow_details ⇒ Types::DownlinkDataflowDetails
Dataflow details for the downlink endpoint
1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1523 class DownlinkAwsGroundStationAgentEndpointDetails < Struct.new( :name, :dataflow_details, :agent_status, :audit_results) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Downlink dataflow endpoint name
1523 1524 1525 1526 1527 1528 1529 1530 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1523 class DownlinkAwsGroundStationAgentEndpointDetails < Struct.new( :name, :dataflow_details, :agent_status, :audit_results) SENSITIVE = [] include Aws::Structure end |