Class: Aws::GroundStation::Types::EndpointDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Information about the endpoint details.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_ground_station_agent_endpointTypes::AwsGroundStationAgentEndpoint

An agent endpoint.



1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
# File 'lib/aws-sdk-groundstation/types.rb', line 1921

class EndpointDetails < Struct.new(
  :security_details,
  :endpoint,
  :aws_ground_station_agent_endpoint,
  :uplink_aws_ground_station_agent_endpoint,
  :downlink_aws_ground_station_agent_endpoint,
  :health_status,
  :health_reasons)
  SENSITIVE = []
  include Aws::Structure
end

Definition for a downlink agent endpoint



1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
# File 'lib/aws-sdk-groundstation/types.rb', line 1921

class EndpointDetails < Struct.new(
  :security_details,
  :endpoint,
  :aws_ground_station_agent_endpoint,
  :uplink_aws_ground_station_agent_endpoint,
  :downlink_aws_ground_station_agent_endpoint,
  :health_status,
  :health_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#endpointTypes::DataflowEndpoint

A dataflow endpoint.



1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
# File 'lib/aws-sdk-groundstation/types.rb', line 1921

class EndpointDetails < Struct.new(
  :security_details,
  :endpoint,
  :aws_ground_station_agent_endpoint,
  :uplink_aws_ground_station_agent_endpoint,
  :downlink_aws_ground_station_agent_endpoint,
  :health_status,
  :health_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#health_reasonsArray<String>

Health reasons for a dataflow endpoint. This field is ignored when calling ‘CreateDataflowEndpointGroup`.

Returns:

  • (Array<String>)


1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
# File 'lib/aws-sdk-groundstation/types.rb', line 1921

class EndpointDetails < Struct.new(
  :security_details,
  :endpoint,
  :aws_ground_station_agent_endpoint,
  :uplink_aws_ground_station_agent_endpoint,
  :downlink_aws_ground_station_agent_endpoint,
  :health_status,
  :health_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#health_statusString

A dataflow endpoint health status. This field is ignored when calling ‘CreateDataflowEndpointGroup`.

Returns:

  • (String)


1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
# File 'lib/aws-sdk-groundstation/types.rb', line 1921

class EndpointDetails < Struct.new(
  :security_details,
  :endpoint,
  :aws_ground_station_agent_endpoint,
  :uplink_aws_ground_station_agent_endpoint,
  :downlink_aws_ground_station_agent_endpoint,
  :health_status,
  :health_reasons)
  SENSITIVE = []
  include Aws::Structure
end

#security_detailsTypes::SecurityDetails

Endpoint security details including a list of subnets, a list of security groups and a role to connect streams to instances.



1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
# File 'lib/aws-sdk-groundstation/types.rb', line 1921

class EndpointDetails < Struct.new(
  :security_details,
  :endpoint,
  :aws_ground_station_agent_endpoint,
  :uplink_aws_ground_station_agent_endpoint,
  :downlink_aws_ground_station_agent_endpoint,
  :health_status,
  :health_reasons)
  SENSITIVE = []
  include Aws::Structure
end

Definition for an uplink agent endpoint



1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
# File 'lib/aws-sdk-groundstation/types.rb', line 1921

class EndpointDetails < Struct.new(
  :security_details,
  :endpoint,
  :aws_ground_station_agent_endpoint,
  :uplink_aws_ground_station_agent_endpoint,
  :downlink_aws_ground_station_agent_endpoint,
  :health_status,
  :health_reasons)
  SENSITIVE = []
  include Aws::Structure
end