Class: Aws::GroundStation::Types::EphemerisData
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::EphemerisData
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
EphemerisData is a union - when making an API calls you must set exactly one of the members.
Ephemeris data.
Defined Under Namespace
Classes: AzEl, Oem, Tle, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#az_el ⇒ Types::AzElEphemeris
Azimuth elevation ephemeris data.
-
#oem ⇒ Types::OEMEphemeris
Ephemeris data in Orbit Ephemeris Message (OEM) format.
-
#tle ⇒ Types::TLEEphemeris
Two-line element set (TLE) ephemeris.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#az_el ⇒ Types::AzElEphemeris
Azimuth elevation ephemeris data.
Use this ephemeris type to provide pointing angles directly, rather than satellite orbital elements. Use this when you need precise antenna pointing but have imprecise or unknown satellite trajectory information.
The azimuth elevation data specifies the antenna pointing direction at specific times relative to a ground station location. AWS Ground Station uses 4th order Lagrange interpolation to compute pointing angles between the provided data points.
AWS Ground Station automatically filters interpolated pointing angles, including only those that are above the site mask elevation of the specified ground station.
For more detail about providing azimuth elevation ephemerides to AWS Ground Station, see the [azimuth elevation ephemeris section] of the AWS Ground Station User Guide.
[1]: docs.aws.amazon.com/ground-station/latest/ug/providing-azimuth-elevation-ephemeris-data.html
1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1992 class EphemerisData < Struct.new( :tle, :oem, :az_el, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tle < EphemerisData; end class Oem < EphemerisData; end class AzEl < EphemerisData; end class Unknown < EphemerisData; end end |
#oem ⇒ Types::OEMEphemeris
Ephemeris data in Orbit Ephemeris Message (OEM) format.
AWS Ground Station processes OEM ephemerides according to the [CCSDS standard] with some extra restrictions. OEM files should be in KVN format. For more detail about the OEM format that AWS Ground Station supports, see [OEM ephemeris format] in the AWS Ground Station user guide.
[1]: ccsds.org/Pubs/502x0b3e1.pdf [2]: docs.aws.amazon.com/ground-station/latest/ug/providing-oem-ephemeris-data.html#oem-ephemeris-format
1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1992 class EphemerisData < Struct.new( :tle, :oem, :az_el, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tle < EphemerisData; end class Oem < EphemerisData; end class AzEl < EphemerisData; end class Unknown < EphemerisData; end end |
#tle ⇒ Types::TLEEphemeris
Two-line element set (TLE) ephemeris.
For more detail about providing Two-line element sets to AWS Ground Station, see the [TLE section] of the AWS Ground Station user guide.
[1]: docs.aws.amazon.com/ground-station/latest/ug/providing-tle-ephemeris-data.html
1992 1993 1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1992 class EphemerisData < Struct.new( :tle, :oem, :az_el, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Tle < EphemerisData; end class Oem < EphemerisData; end class AzEl < EphemerisData; end class Unknown < EphemerisData; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1992 1993 1994 |
# File 'lib/aws-sdk-groundstation/types.rb', line 1992 def unknown @unknown end |