Class: Aws::GroundStation::Types::EphemerisItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Ephemeris item.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_time ⇒ Time

The time the ephemeris was uploaded in UTC.

Returns:

  • (Time)


2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
# File 'lib/aws-sdk-groundstation/types.rb', line 2131

class EphemerisItem < Struct.new(
  :ephemeris_id,
  :ephemeris_type,
  :status,
  :priority,
  :enabled,
  :creation_time,
  :name,
  :source_s3_object)
  SENSITIVE = []
  include Aws::Structure
end

#enabled ⇒ Boolean

Whether or not the ephemeris is enabled.

Returns:

  • (Boolean)


2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
# File 'lib/aws-sdk-groundstation/types.rb', line 2131

class EphemerisItem < Struct.new(
  :ephemeris_id,
  :ephemeris_type,
  :status,
  :priority,
  :enabled,
  :creation_time,
  :name,
  :source_s3_object)
  SENSITIVE = []
  include Aws::Structure
end

#ephemeris_id ⇒ String

The AWS Ground Station ephemeris ID.

Returns:

  • (String)


2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
# File 'lib/aws-sdk-groundstation/types.rb', line 2131

class EphemerisItem < Struct.new(
  :ephemeris_id,
  :ephemeris_type,
  :status,
  :priority,
  :enabled,
  :creation_time,
  :name,
  :source_s3_object)
  SENSITIVE = []
  include Aws::Structure
end

#ephemeris_type ⇒ String

The type of ephemeris.

Returns:

  • (String)


2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
# File 'lib/aws-sdk-groundstation/types.rb', line 2131

class EphemerisItem < Struct.new(
  :ephemeris_id,
  :ephemeris_type,
  :status,
  :priority,
  :enabled,
  :creation_time,
  :name,
  :source_s3_object)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

A name that you can use to identify the ephemeris.

Returns:

  • (String)


2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
# File 'lib/aws-sdk-groundstation/types.rb', line 2131

class EphemerisItem < Struct.new(
  :ephemeris_id,
  :ephemeris_type,
  :status,
  :priority,
  :enabled,
  :creation_time,
  :name,
  :source_s3_object)
  SENSITIVE = []
  include Aws::Structure
end

#priority ⇒ Integer

A priority score that determines which ephemeris to use when multiple ephemerides overlap.

Higher numbers take precedence. The default is 1. Must be 1 or greater.

Returns:

  • (Integer)


2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
# File 'lib/aws-sdk-groundstation/types.rb', line 2131

class EphemerisItem < Struct.new(
  :ephemeris_id,
  :ephemeris_type,
  :status,
  :priority,
  :enabled,
  :creation_time,
  :name,
  :source_s3_object)
  SENSITIVE = []
  include Aws::Structure
end

#source_s3_object ⇒ Types::S3Object

Source Amazon S3 object used for the ephemeris.

Returns:



2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
# File 'lib/aws-sdk-groundstation/types.rb', line 2131

class EphemerisItem < Struct.new(
  :ephemeris_id,
  :ephemeris_type,
  :status,
  :priority,
  :enabled,
  :creation_time,
  :name,
  :source_s3_object)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The status of the ephemeris.

Returns:

  • (String)


2131
2132
2133
2134
2135
2136
2137
2138
2139
2140
2141
2142
# File 'lib/aws-sdk-groundstation/types.rb', line 2131

class EphemerisItem < Struct.new(
  :ephemeris_id,
  :ephemeris_type,
  :status,
  :priority,
  :enabled,
  :creation_time,
  :name,
  :source_s3_object)
  SENSITIVE = []
  include Aws::Structure
end