Class: Aws::GroundStation::Types::GetMinuteUsageRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Input for the ‘GetMinuteUsage` operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#monthInteger

The month being requested, with a value of 1-12.

Returns:

  • (Integer)


2482
2483
2484
2485
2486
2487
# File 'lib/aws-sdk-groundstation/types.rb', line 2482

class GetMinuteUsageRequest < Struct.new(
  :month,
  :year)
  SENSITIVE = []
  include Aws::Structure
end

#yearInteger

The year being requested, in the format of YYYY.

Returns:

  • (Integer)


2482
2483
2484
2485
2486
2487
# File 'lib/aws-sdk-groundstation/types.rb', line 2482

class GetMinuteUsageRequest < Struct.new(
  :month,
  :year)
  SENSITIVE = []
  include Aws::Structure
end