Class: Aws::GroundStation::Types::GetMinuteUsageResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::GetMinuteUsageResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Output for the ‘GetMinuteUsage` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#estimated_minutes_remaining ⇒ Integer
Estimated number of minutes remaining for an account, specific to the month being requested.
-
#is_reserved_minutes_customer ⇒ Boolean
Returns whether or not an account has signed up for the reserved minutes pricing plan, specific to the month being requested.
-
#total_reserved_minute_allocation ⇒ Integer
Total number of reserved minutes allocated, specific to the month being requested.
-
#total_scheduled_minutes ⇒ Integer
Total scheduled minutes for an account, specific to the month being requested.
-
#upcoming_minutes_scheduled ⇒ Integer
Upcoming minutes scheduled for an account, specific to the month being requested.
Instance Attribute Details
#estimated_minutes_remaining ⇒ Integer
Estimated number of minutes remaining for an account, specific to the month being requested.
2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2518 class GetMinuteUsageResponse < Struct.new( :is_reserved_minutes_customer, :total_reserved_minute_allocation, :upcoming_minutes_scheduled, :total_scheduled_minutes, :estimated_minutes_remaining) SENSITIVE = [] include Aws::Structure end |
#is_reserved_minutes_customer ⇒ Boolean
Returns whether or not an account has signed up for the reserved minutes pricing plan, specific to the month being requested.
2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2518 class GetMinuteUsageResponse < Struct.new( :is_reserved_minutes_customer, :total_reserved_minute_allocation, :upcoming_minutes_scheduled, :total_scheduled_minutes, :estimated_minutes_remaining) SENSITIVE = [] include Aws::Structure end |
#total_reserved_minute_allocation ⇒ Integer
Total number of reserved minutes allocated, specific to the month being requested.
2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2518 class GetMinuteUsageResponse < Struct.new( :is_reserved_minutes_customer, :total_reserved_minute_allocation, :upcoming_minutes_scheduled, :total_scheduled_minutes, :estimated_minutes_remaining) SENSITIVE = [] include Aws::Structure end |
#total_scheduled_minutes ⇒ Integer
Total scheduled minutes for an account, specific to the month being requested.
2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2518 class GetMinuteUsageResponse < Struct.new( :is_reserved_minutes_customer, :total_reserved_minute_allocation, :upcoming_minutes_scheduled, :total_scheduled_minutes, :estimated_minutes_remaining) SENSITIVE = [] include Aws::Structure end |
#upcoming_minutes_scheduled ⇒ Integer
Upcoming minutes scheduled for an account, specific to the month being requested.
2518 2519 2520 2521 2522 2523 2524 2525 2526 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2518 class GetMinuteUsageResponse < Struct.new( :is_reserved_minutes_customer, :total_reserved_minute_allocation, :upcoming_minutes_scheduled, :total_scheduled_minutes, :estimated_minutes_remaining) SENSITIVE = [] include Aws::Structure end |