Class: Aws::GroundStation::Types::GetMissionProfileResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::GetMissionProfileResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Output for the ‘GetMissionProfile` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_post_pass_duration_seconds ⇒ Integer
Amount of time after a contact ends that you’d like to receive a CloudWatch event indicating the pass has finished.
-
#contact_pre_pass_duration_seconds ⇒ Integer
Amount of time prior to contact start you’d like to receive a CloudWatch event indicating an upcoming pass.
-
#dataflow_edges ⇒ Array<Array<String>>
A list of lists of ARNs.
-
#minimum_viable_contact_duration_seconds ⇒ Integer
Smallest amount of time in seconds that you’d like to see for an available contact.
-
#mission_profile_arn ⇒ String
ARN of a mission profile.
-
#mission_profile_id ⇒ String
UUID of a mission profile.
-
#name ⇒ String
Name of a mission profile.
-
#region ⇒ String
Region of a mission profile.
-
#streams_kms_key ⇒ Types::KmsKey
KMS key to use for encrypting streams.
-
#streams_kms_role ⇒ String
Role to use for encrypting streams with KMS key.
-
#tags ⇒ Hash<String,String>
Tags assigned to a mission profile.
-
#telemetry_sink_config_arn ⇒ String
ARN of a telemetry sink ‘Config`.
-
#tracking_config_arn ⇒ String
ARN of a tracking ‘Config`.
Instance Attribute Details
#contact_post_pass_duration_seconds ⇒ Integer
Amount of time after a contact ends that you’d like to receive a CloudWatch event indicating the pass has finished.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#contact_pre_pass_duration_seconds ⇒ Integer
Amount of time prior to contact start you’d like to receive a CloudWatch event indicating an upcoming pass.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#dataflow_edges ⇒ Array<Array<String>>
A list of lists of ARNs. Each list of ARNs is an edge, with a from ‘ Config` and a to `Config`.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#minimum_viable_contact_duration_seconds ⇒ Integer
Smallest amount of time in seconds that you’d like to see for an available contact. AWS Ground Station will not present you with contacts shorter than this duration.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#mission_profile_arn ⇒ String
ARN of a mission profile.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#mission_profile_id ⇒ String
UUID of a mission profile.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of a mission profile.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#region ⇒ String
Region of a mission profile.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#streams_kms_key ⇒ Types::KmsKey
KMS key to use for encrypting streams.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#streams_kms_role ⇒ String
Role to use for encrypting streams with KMS key.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags assigned to a mission profile.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#telemetry_sink_config_arn ⇒ String
ARN of a telemetry sink ‘Config`.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#tracking_config_arn ⇒ String
ARN of a tracking ‘Config`.
2603 2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 2614 2615 2616 2617 2618 2619 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2603 class GetMissionProfileResponse < Struct.new( :mission_profile_id, :mission_profile_arn, :name, :region, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :tags, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |