Class: Aws::GroundStation::Types::GetSatelliteResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::GetSatelliteResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Output for the ‘GetSatellite` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_ephemeris ⇒ Types::EphemerisMetaData
The current ephemeris being used to compute the trajectory of the satellite.
-
#ground_stations ⇒ Array<String>
A list of ground stations to which the satellite is on-boarded.
-
#norad_satellite_id ⇒ Integer
NORAD satellite ID number.
-
#satellite_arn ⇒ String
ARN of a satellite.
-
#satellite_id ⇒ String
UUID of a satellite.
Instance Attribute Details
#current_ephemeris ⇒ Types::EphemerisMetaData
The current ephemeris being used to compute the trajectory of the satellite.
2660 2661 2662 2663 2664 2665 2666 2667 2668 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2660 class GetSatelliteResponse < Struct.new( :satellite_id, :satellite_arn, :norad_satellite_id, :ground_stations, :current_ephemeris) SENSITIVE = [] include Aws::Structure end |
#ground_stations ⇒ Array<String>
A list of ground stations to which the satellite is on-boarded.
2660 2661 2662 2663 2664 2665 2666 2667 2668 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2660 class GetSatelliteResponse < Struct.new( :satellite_id, :satellite_arn, :norad_satellite_id, :ground_stations, :current_ephemeris) SENSITIVE = [] include Aws::Structure end |
#norad_satellite_id ⇒ Integer
NORAD satellite ID number.
2660 2661 2662 2663 2664 2665 2666 2667 2668 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2660 class GetSatelliteResponse < Struct.new( :satellite_id, :satellite_arn, :norad_satellite_id, :ground_stations, :current_ephemeris) SENSITIVE = [] include Aws::Structure end |
#satellite_arn ⇒ String
ARN of a satellite.
2660 2661 2662 2663 2664 2665 2666 2667 2668 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2660 class GetSatelliteResponse < Struct.new( :satellite_id, :satellite_arn, :norad_satellite_id, :ground_stations, :current_ephemeris) SENSITIVE = [] include Aws::Structure end |
#satellite_id ⇒ String
UUID of a satellite.
2660 2661 2662 2663 2664 2665 2666 2667 2668 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2660 class GetSatelliteResponse < Struct.new( :satellite_id, :satellite_arn, :norad_satellite_id, :ground_stations, :current_ephemeris) SENSITIVE = [] include Aws::Structure end |