Class: Aws::GroundStation::Types::GroundStationReservationListItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Item in a list of ground station reservations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#antenna_name ⇒ String

Name of an antenna.

Returns:

  • (String)


2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
# File 'lib/aws-sdk-groundstation/types.rb', line 2722

class GroundStationReservationListItem < Struct.new(
  :reservation_type,
  :ground_station_id,
  :antenna_name,
  :start_time,
  :end_time,
  :reservation_details)
  SENSITIVE = []
  include Aws::Structure
end

#end_time ⇒ Time

End time of a ground station reservation in UTC.

Returns:

  • (Time)


2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
# File 'lib/aws-sdk-groundstation/types.rb', line 2722

class GroundStationReservationListItem < Struct.new(
  :reservation_type,
  :ground_station_id,
  :antenna_name,
  :start_time,
  :end_time,
  :reservation_details)
  SENSITIVE = []
  include Aws::Structure
end

#ground_station_id ⇒ String

ID of a ground station.

Returns:

  • (String)


2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
# File 'lib/aws-sdk-groundstation/types.rb', line 2722

class GroundStationReservationListItem < Struct.new(
  :reservation_type,
  :ground_station_id,
  :antenna_name,
  :start_time,
  :end_time,
  :reservation_details)
  SENSITIVE = []
  include Aws::Structure
end

#reservation_details ⇒ Types::ReservationDetails

Details of a ground station reservation.



2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
# File 'lib/aws-sdk-groundstation/types.rb', line 2722

class GroundStationReservationListItem < Struct.new(
  :reservation_type,
  :ground_station_id,
  :antenna_name,
  :start_time,
  :end_time,
  :reservation_details)
  SENSITIVE = []
  include Aws::Structure
end

#reservation_type ⇒ String

Type of a ground station reservation.

Returns:

  • (String)


2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
# File 'lib/aws-sdk-groundstation/types.rb', line 2722

class GroundStationReservationListItem < Struct.new(
  :reservation_type,
  :ground_station_id,
  :antenna_name,
  :start_time,
  :end_time,
  :reservation_details)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ Time

Start time of a ground station reservation in UTC.

Returns:

  • (Time)


2722
2723
2724
2725
2726
2727
2728
2729
2730
2731
# File 'lib/aws-sdk-groundstation/types.rb', line 2722

class GroundStationReservationListItem < Struct.new(
  :reservation_type,
  :ground_station_id,
  :antenna_name,
  :start_time,
  :end_time,
  :reservation_details)
  SENSITIVE = []
  include Aws::Structure
end