Class: Aws::GroundStation::Types::ListConfigsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::ListConfigsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Output for the ListConfigs operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#config_list ⇒ Array<Types::ConfigListItem>
List of
Configitems. -
#next_token ⇒ String
Next token returned in the response of a previous
ListConfigscall.
Instance Attribute Details
#config_list ⇒ Array<Types::ConfigListItem>
List of Config items.
2921 2922 2923 2924 2925 2926 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2921 class ListConfigsResponse < Struct.new( :next_token, :config_list) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Next token returned in the response of a previous ListConfigs
call. Used to get the next page of results.
2921 2922 2923 2924 2925 2926 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2921 class ListConfigsResponse < Struct.new( :next_token, :config_list) SENSITIVE = [] include Aws::Structure end |