Class: Aws::GroundStation::Types::ListContactVersionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contact_versions_list ⇒ Array<Types::ContactVersion>

List of contact versions.

Returns:



2962
2963
2964
2965
2966
2967
# File 'lib/aws-sdk-groundstation/types.rb', line 2962

class ListContactVersionsResponse < Struct.new(
  :next_token,
  :contact_versions_list)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Next token to be used in a subsequent ListContactVersions call to retrieve the next page of results.

Returns:

  • (String)


2962
2963
2964
2965
2966
2967
# File 'lib/aws-sdk-groundstation/types.rb', line 2962

class ListContactVersionsResponse < Struct.new(
  :next_token,
  :contact_versions_list)
  SENSITIVE = []
  include Aws::Structure
end