Class: Aws::GroundStation::Types::ListContactsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Input for the ListContacts operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_time ⇒ Time

End time of a contact in UTC.

Returns:

  • (Time)


3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
# File 'lib/aws-sdk-groundstation/types.rb', line 3010

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#ephemeris ⇒ Types::EphemerisFilter

Filter for selecting contacts that use a specific ephemeris".



3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
# File 'lib/aws-sdk-groundstation/types.rb', line 3010

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#ground_station ⇒ String

Name of a ground station.

Returns:

  • (String)


3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
# File 'lib/aws-sdk-groundstation/types.rb', line 3010

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#max_results ⇒ Integer

Maximum number of contacts returned.

Returns:

  • (Integer)


3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
# File 'lib/aws-sdk-groundstation/types.rb', line 3010

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#mission_profile_arn ⇒ String

ARN of a mission profile.

Returns:

  • (String)


3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
# File 'lib/aws-sdk-groundstation/types.rb', line 3010

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Next token returned in the request of a previous ListContacts call. Used to get the next page of results.

Returns:

  • (String)


3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
# File 'lib/aws-sdk-groundstation/types.rb', line 3010

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#satellite_arn ⇒ String

ARN of a satellite.

Returns:

  • (String)


3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
# File 'lib/aws-sdk-groundstation/types.rb', line 3010

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#start_time ⇒ Time

Start time of a contact in UTC.

Returns:

  • (Time)


3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
# File 'lib/aws-sdk-groundstation/types.rb', line 3010

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#status_list ⇒ Array<String>

Status of a contact reservation.

Returns:

  • (Array<String>)


3010
3011
3012
3013
3014
3015
3016
3017
3018
3019
3020
3021
3022
# File 'lib/aws-sdk-groundstation/types.rb', line 3010

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end