Class: Aws::GroundStation::Types::ListContactsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::ListContactsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Output for the ListContacts operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_list ⇒ Array<Types::ContactData>
List of contacts.
-
#next_token ⇒ String
Next token returned in the response of a previous
ListContactscall.
Instance Attribute Details
#contact_list ⇒ Array<Types::ContactData>
List of contacts.
3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3037 class ListContactsResponse < Struct.new( :next_token, :contact_list) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Next token returned in the response of a previous ListContacts
call. Used to get the next page of results.
3037 3038 3039 3040 3041 3042 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3037 class ListContactsResponse < Struct.new( :next_token, :contact_list) SENSITIVE = [] include Aws::Structure end |