Class: Aws::GroundStation::Types::ListDataflowEndpointGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::ListDataflowEndpointGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Input for the ListDataflowEndpointGroups operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Maximum number of dataflow endpoint groups returned.
-
#next_token ⇒ String
Next token returned in the request of a previous
ListDataflowEndpointGroupscall.
Instance Attribute Details
#max_results ⇒ Integer
Maximum number of dataflow endpoint groups returned.
3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3058 class ListDataflowEndpointGroupsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Next token returned in the request of a previous
ListDataflowEndpointGroups call. Used to get the next page of
results.
3058 3059 3060 3061 3062 3063 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3058 class ListDataflowEndpointGroupsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |