Class: Aws::GroundStation::Types::ListGroundStationReservationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::ListGroundStationReservationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
End time of the reservation window in UTC.
-
#ground_station_id ⇒ String
ID of a ground station.
-
#max_results ⇒ Integer
Maximum number of ground station reservations returned.
-
#next_token ⇒ String
Next token returned in the request of a previous
ListGroundStationReservationscall. -
#reservation_types ⇒ Array<String>
Types of reservations to filter by.
-
#start_time ⇒ Time
Start time of the reservation window in UTC.
Instance Attribute Details
#end_time ⇒ Time
End time of the reservation window in UTC.
3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3176 class ListGroundStationReservationsRequest < Struct.new( :ground_station_id, :start_time, :end_time, :reservation_types, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#ground_station_id ⇒ String
ID of a ground station.
3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3176 class ListGroundStationReservationsRequest < Struct.new( :ground_station_id, :start_time, :end_time, :reservation_types, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
Maximum number of ground station reservations returned.
3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3176 class ListGroundStationReservationsRequest < Struct.new( :ground_station_id, :start_time, :end_time, :reservation_types, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Next token returned in the request of a previous
ListGroundStationReservations call. Used to get the next page of
results.
3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3176 class ListGroundStationReservationsRequest < Struct.new( :ground_station_id, :start_time, :end_time, :reservation_types, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#reservation_types ⇒ Array<String>
Types of reservations to filter by.
3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3176 class ListGroundStationReservationsRequest < Struct.new( :ground_station_id, :start_time, :end_time, :reservation_types, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
Start time of the reservation window in UTC.
3176 3177 3178 3179 3180 3181 3182 3183 3184 3185 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3176 class ListGroundStationReservationsRequest < Struct.new( :ground_station_id, :start_time, :end_time, :reservation_types, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |