Class: Aws::GroundStation::Types::ListGroundStationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Input for the ListGroundStations operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

Maximum number of ground stations returned.

Returns:

  • (Integer)


3223
3224
3225
3226
3227
3228
3229
# File 'lib/aws-sdk-groundstation/types.rb', line 3223

class ListGroundStationsRequest < Struct.new(
  :satellite_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Next token that can be supplied in the next call to get the next page of ground stations.

Returns:

  • (String)


3223
3224
3225
3226
3227
3228
3229
# File 'lib/aws-sdk-groundstation/types.rb', line 3223

class ListGroundStationsRequest < Struct.new(
  :satellite_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#satellite_id ⇒ String

Satellite ID to retrieve on-boarded ground stations.

Returns:

  • (String)


3223
3224
3225
3226
3227
3228
3229
# File 'lib/aws-sdk-groundstation/types.rb', line 3223

class ListGroundStationsRequest < Struct.new(
  :satellite_id,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end