Class: Aws::GroundStation::Types::ListGroundStationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Output for the ListGroundStations operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ground_station_list ⇒ Array<Types::GroundStationData>

List of ground stations.

Returns:



3244
3245
3246
3247
3248
3249
# File 'lib/aws-sdk-groundstation/types.rb', line 3244

class ListGroundStationsResponse < Struct.new(
  :next_token,
  :ground_station_list)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Next token that can be supplied in the next call to get the next page of ground stations.

Returns:



3244
3245
3246
3247
3248
3249
# File 'lib/aws-sdk-groundstation/types.rb', line 3244

class ListGroundStationsResponse < Struct.new(
  :next_token,
  :ground_station_list)
  SENSITIVE = []
  include Aws::Structure
end