Class: Aws::GroundStation::Types::ListMissionProfilesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::ListMissionProfilesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Output for the ListMissionProfiles operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#mission_profile_list ⇒ Array<Types::MissionProfileListItem>
List of mission profiles.
-
#next_token ⇒ String
Next token returned in the response of a previous
ListMissionProfilescall.
Instance Attribute Details
#mission_profile_list ⇒ Array<Types::MissionProfileListItem>
List of mission profiles.
3284 3285 3286 3287 3288 3289 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3284 class ListMissionProfilesResponse < Struct.new( :next_token, :mission_profile_list) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Next token returned in the response of a previous
ListMissionProfiles call. Used to get the next page of results.
3284 3285 3286 3287 3288 3289 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3284 class ListMissionProfilesResponse < Struct.new( :next_token, :mission_profile_list) SENSITIVE = [] include Aws::Structure end |