Class: Aws::GroundStation::Types::ListSatellitesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Input for the ListSatellites operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

Maximum number of satellites returned.

Returns:



3304
3305
3306
3307
3308
3309
# File 'lib/aws-sdk-groundstation/types.rb', line 3304

class ListSatellitesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

Next token that can be supplied in the next call to get the next page of satellites.

Returns:



3304
3305
3306
3307
3308
3309
# File 'lib/aws-sdk-groundstation/types.rb', line 3304

class ListSatellitesRequest < Struct.new(
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end