Class: Aws::GroundStation::Types::ProgramTrackSettings

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Note:

ProgramTrackSettings is a union - when making an API calls you must set exactly one of the members.

Note:

ProgramTrackSettings is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ProgramTrackSettings corresponding to the set member.

Program track settings for an antenna during a contact.

Direct Known Subclasses

AzEl, Oem, Tle, Unknown

Defined Under Namespace

Classes: AzEl, Oem, Tle, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#az_elTypes::AzElProgramTrackSettings

Program track settings for AzElEphemeris.



3481
3482
3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
# File 'lib/aws-sdk-groundstation/types.rb', line 3481

class ProgramTrackSettings < Struct.new(
  :az_el,
  :oem,
  :tle,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AzEl < ProgramTrackSettings; end
  class Oem < ProgramTrackSettings; end
  class Tle < ProgramTrackSettings; end
  class Unknown < ProgramTrackSettings; end
end

#oemTypes::OemProgramTrackSettings

Program track settings for OEMEphemeris.



3481
3482
3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
# File 'lib/aws-sdk-groundstation/types.rb', line 3481

class ProgramTrackSettings < Struct.new(
  :az_el,
  :oem,
  :tle,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AzEl < ProgramTrackSettings; end
  class Oem < ProgramTrackSettings; end
  class Tle < ProgramTrackSettings; end
  class Unknown < ProgramTrackSettings; end
end

#tleTypes::TleProgramTrackSettings

Program track settings for TLEEphemeris.



3481
3482
3483
3484
3485
3486
3487
3488
3489
3490
3491
3492
3493
3494
# File 'lib/aws-sdk-groundstation/types.rb', line 3481

class ProgramTrackSettings < Struct.new(
  :az_el,
  :oem,
  :tle,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AzEl < ProgramTrackSettings; end
  class Oem < ProgramTrackSettings; end
  class Tle < ProgramTrackSettings; end
  class Unknown < ProgramTrackSettings; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



3481
3482
3483
# File 'lib/aws-sdk-groundstation/types.rb', line 3481

def unknown
  @unknown
end