Class: Aws::GroundStation::Types::ResourceLimitExceededException
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::ResourceLimitExceededException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Account limits for this resource have been exceeded.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #message ⇒ String
-
#parameter_name ⇒ String
Name of the parameter that exceeded the resource limit.
Instance Attribute Details
#message ⇒ String
3666 3667 3668 3669 3670 3671 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3666 class ResourceLimitExceededException < Struct.new( :message, :parameter_name) SENSITIVE = [] include Aws::Structure end |
#parameter_name ⇒ String
Name of the parameter that exceeded the resource limit.
3666 3667 3668 3669 3670 3671 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3666 class ResourceLimitExceededException < Struct.new( :message, :parameter_name) SENSITIVE = [] include Aws::Structure end |