Class: Aws::GroundStation::Types::SatelliteListItem

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Item in a list of satellites.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_ephemeris ⇒ Types::EphemerisMetaData

The current ephemeris being used to compute the trajectory of the satellite.



3779
3780
3781
3782
3783
3784
3785
3786
3787
# File 'lib/aws-sdk-groundstation/types.rb', line 3779

class SatelliteListItem < Struct.new(
  :satellite_id,
  :satellite_arn,
  :norad_satellite_id,
  :ground_stations,
  :current_ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#ground_stations ⇒ Array<String>

A list of ground stations to which the satellite is on-boarded.

Returns:

  • (Array<String>)


3779
3780
3781
3782
3783
3784
3785
3786
3787
# File 'lib/aws-sdk-groundstation/types.rb', line 3779

class SatelliteListItem < Struct.new(
  :satellite_id,
  :satellite_arn,
  :norad_satellite_id,
  :ground_stations,
  :current_ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#norad_satellite_id ⇒ Integer

NORAD satellite ID number.

Returns:

  • (Integer)


3779
3780
3781
3782
3783
3784
3785
3786
3787
# File 'lib/aws-sdk-groundstation/types.rb', line 3779

class SatelliteListItem < Struct.new(
  :satellite_id,
  :satellite_arn,
  :norad_satellite_id,
  :ground_stations,
  :current_ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#satellite_arn ⇒ String

ARN of a satellite.

Returns:

  • (String)


3779
3780
3781
3782
3783
3784
3785
3786
3787
# File 'lib/aws-sdk-groundstation/types.rb', line 3779

class SatelliteListItem < Struct.new(
  :satellite_id,
  :satellite_arn,
  :norad_satellite_id,
  :ground_stations,
  :current_ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#satellite_id ⇒ String

UUID of a satellite.

Returns:

  • (String)


3779
3780
3781
3782
3783
3784
3785
3786
3787
# File 'lib/aws-sdk-groundstation/types.rb', line 3779

class SatelliteListItem < Struct.new(
  :satellite_id,
  :satellite_arn,
  :norad_satellite_id,
  :ground_stations,
  :current_ephemeris)
  SENSITIVE = []
  include Aws::Structure
end