Class: Aws::GroundStation::Types::TelemetrySinkConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::TelemetrySinkConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Information about a telemetry sink ‘Config`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#telemetry_sink_data ⇒ Types::TelemetrySinkData
Information about the telemetry sink specified by the ‘telemetrySinkType`.
-
#telemetry_sink_type ⇒ String
The type of telemetry sink.
Instance Attribute Details
#telemetry_sink_data ⇒ Types::TelemetrySinkData
Information about the telemetry sink specified by the ‘telemetrySinkType`.
3433 3434 3435 3436 3437 3438 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3433 class TelemetrySinkConfig < Struct.new( :telemetry_sink_type, :telemetry_sink_data) SENSITIVE = [] include Aws::Structure end |
#telemetry_sink_type ⇒ String
The type of telemetry sink.
3433 3434 3435 3436 3437 3438 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3433 class TelemetrySinkConfig < Struct.new( :telemetry_sink_type, :telemetry_sink_data) SENSITIVE = [] include Aws::Structure end |