Class: Aws::GroundStation::Types::TelemetrySinkData

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Note:

TelemetrySinkData is a union - when making an API calls you must set exactly one of the members.

Note:

TelemetrySinkData is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of TelemetrySinkData corresponding to the set member.

Information about a telemetry sink.

Direct Known Subclasses

KinesisDataStreamData, Unknown

Defined Under Namespace

Classes: KinesisDataStreamData, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kinesis_data_stream_dataTypes::KinesisDataStreamData

Information about a telemetry sink of type ‘KINESIS_DATA_STREAM`.



4028
4029
4030
4031
4032
4033
4034
4035
4036
4037
# File 'lib/aws-sdk-groundstation/types.rb', line 4028

class TelemetrySinkData < Struct.new(
  :kinesis_data_stream_data,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class KinesisDataStreamData < TelemetrySinkData; end
  class Unknown < TelemetrySinkData; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4028
4029
4030
# File 'lib/aws-sdk-groundstation/types.rb', line 4028

def unknown
  @unknown
end