Class: Aws::GroundStation::Types::UpdateContactRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A client token is a unique, case-sensitive string of up to 64 ASCII characters. It is generated by the client to ensure idempotent operations, allowing safe retries without unintended side effects.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


4273
4274
4275
4276
4277
4278
4279
4280
# File 'lib/aws-sdk-groundstation/types.rb', line 4273

class UpdateContactRequest < Struct.new(
  :contact_id,
  :client_token,
  :tracking_overrides,
  :satellite_arn)
  SENSITIVE = []
  include Aws::Structure
end

#contact_idString

UUID of a contact.

Returns:

  • (String)


4273
4274
4275
4276
4277
4278
4279
4280
# File 'lib/aws-sdk-groundstation/types.rb', line 4273

class UpdateContactRequest < Struct.new(
  :contact_id,
  :client_token,
  :tracking_overrides,
  :satellite_arn)
  SENSITIVE = []
  include Aws::Structure
end

#satellite_arnString

ARN of a satellite.

Returns:

  • (String)


4273
4274
4275
4276
4277
4278
4279
4280
# File 'lib/aws-sdk-groundstation/types.rb', line 4273

class UpdateContactRequest < Struct.new(
  :contact_id,
  :client_token,
  :tracking_overrides,
  :satellite_arn)
  SENSITIVE = []
  include Aws::Structure
end

#tracking_overridesTypes::TrackingOverrides

Overrides the default tracking configuration on an antenna during a contact.



4273
4274
4275
4276
4277
4278
4279
4280
# File 'lib/aws-sdk-groundstation/types.rb', line 4273

class UpdateContactRequest < Struct.new(
  :contact_id,
  :client_token,
  :tracking_overrides,
  :satellite_arn)
  SENSITIVE = []
  include Aws::Structure
end