Class: Aws::GroundStation::Types::UpdateEphemerisRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::UpdateEphemerisRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
Enable or disable the ephemeris.
-
#ephemeris_id ⇒ String
The AWS Ground Station ephemeris ID.
-
#name ⇒ String
A name that you can use to identify the ephemeris.
-
#priority ⇒ Integer
A priority score that determines which ephemeris to use when multiple ephemerides overlap.
Instance Attribute Details
#enabled ⇒ Boolean
Enable or disable the ephemeris. Changing this value doesn’t require re-validation.
4322 4323 4324 4325 4326 4327 4328 4329 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4322 class UpdateEphemerisRequest < Struct.new( :ephemeris_id, :enabled, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#ephemeris_id ⇒ String
The AWS Ground Station ephemeris ID.
4322 4323 4324 4325 4326 4327 4328 4329 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4322 class UpdateEphemerisRequest < Struct.new( :ephemeris_id, :enabled, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name that you can use to identify the ephemeris.
4322 4323 4324 4325 4326 4327 4328 4329 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4322 class UpdateEphemerisRequest < Struct.new( :ephemeris_id, :enabled, :name, :priority) SENSITIVE = [] include Aws::Structure end |
#priority ⇒ Integer
A priority score that determines which ephemeris to use when multiple ephemerides overlap.
Higher numbers take precedence. The default is 1. Must be 1 or greater.
4322 4323 4324 4325 4326 4327 4328 4329 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4322 class UpdateEphemerisRequest < Struct.new( :ephemeris_id, :enabled, :name, :priority) SENSITIVE = [] include Aws::Structure end |