Class: Aws::GroundStation::Types::UpdateMissionProfileRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::UpdateMissionProfileRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Input for the ‘UpdateMissionProfile` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_post_pass_duration_seconds ⇒ Integer
Amount of time after a contact ends that you’d like to receive a Ground Station Contact State Change event indicating the pass has finished.
-
#contact_pre_pass_duration_seconds ⇒ Integer
Amount of time after a contact ends that you’d like to receive a Ground Station Contact State Change event indicating the pass has finished.
-
#dataflow_edges ⇒ Array<Array<String>>
A list of lists of ARNs.
-
#minimum_viable_contact_duration_seconds ⇒ Integer
Smallest amount of time in seconds that you’d like to see for an available contact.
-
#mission_profile_id ⇒ String
UUID of a mission profile.
-
#name ⇒ String
Name of a mission profile.
-
#streams_kms_key ⇒ Types::KmsKey
KMS key to use for encrypting streams.
-
#streams_kms_role ⇒ String
Role to use for encrypting streams with KMS key.
-
#telemetry_sink_config_arn ⇒ String
ARN of a telemetry sink ‘Config`.
-
#tracking_config_arn ⇒ String
ARN of a tracking ‘Config`.
Instance Attribute Details
#contact_post_pass_duration_seconds ⇒ Integer
Amount of time after a contact ends that you’d like to receive a Ground Station Contact State Change event indicating the pass has finished.
4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4382 class UpdateMissionProfileRequest < Struct.new( :mission_profile_id, :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#contact_pre_pass_duration_seconds ⇒ Integer
Amount of time after a contact ends that you’d like to receive a Ground Station Contact State Change event indicating the pass has finished.
4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4382 class UpdateMissionProfileRequest < Struct.new( :mission_profile_id, :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#dataflow_edges ⇒ Array<Array<String>>
A list of lists of ARNs. Each list of ARNs is an edge, with a from ‘ Config` and a to `Config`.
4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4382 class UpdateMissionProfileRequest < Struct.new( :mission_profile_id, :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#minimum_viable_contact_duration_seconds ⇒ Integer
Smallest amount of time in seconds that you’d like to see for an available contact. AWS Ground Station will not present you with contacts shorter than this duration.
4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4382 class UpdateMissionProfileRequest < Struct.new( :mission_profile_id, :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#mission_profile_id ⇒ String
UUID of a mission profile.
4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4382 class UpdateMissionProfileRequest < Struct.new( :mission_profile_id, :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name of a mission profile.
4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4382 class UpdateMissionProfileRequest < Struct.new( :mission_profile_id, :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#streams_kms_key ⇒ Types::KmsKey
KMS key to use for encrypting streams.
4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4382 class UpdateMissionProfileRequest < Struct.new( :mission_profile_id, :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#streams_kms_role ⇒ String
Role to use for encrypting streams with KMS key.
4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4382 class UpdateMissionProfileRequest < Struct.new( :mission_profile_id, :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#telemetry_sink_config_arn ⇒ String
ARN of a telemetry sink ‘Config`.
4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4382 class UpdateMissionProfileRequest < Struct.new( :mission_profile_id, :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |
#tracking_config_arn ⇒ String
ARN of a tracking ‘Config`.
4382 4383 4384 4385 4386 4387 4388 4389 4390 4391 4392 4393 4394 4395 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4382 class UpdateMissionProfileRequest < Struct.new( :mission_profile_id, :name, :contact_pre_pass_duration_seconds, :contact_post_pass_duration_seconds, :minimum_viable_contact_duration_seconds, :dataflow_edges, :tracking_config_arn, :telemetry_sink_config_arn, :streams_kms_key, :streams_kms_role) SENSITIVE = [] include Aws::Structure end |