Class: Aws::GroundStation::Types::UplinkAwsGroundStationAgentEndpointDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::UplinkAwsGroundStationAgentEndpointDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Details for an uplink agent endpoint
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_status ⇒ String
Status of the agent associated with the uplink dataflow endpoint.
-
#audit_results ⇒ String
Health audit results for the uplink dataflow endpoint.
-
#dataflow_details ⇒ Types::UplinkDataflowDetails
Dataflow details for the uplink endpoint.
-
#name ⇒ String
Uplink dataflow endpoint name.
Instance Attribute Details
#agent_status ⇒ String
Status of the agent associated with the uplink dataflow endpoint
3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3788 class UplinkAwsGroundStationAgentEndpointDetails < Struct.new( :name, :dataflow_details, :agent_status, :audit_results) SENSITIVE = [] include Aws::Structure end |
#audit_results ⇒ String
Health audit results for the uplink dataflow endpoint
3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3788 class UplinkAwsGroundStationAgentEndpointDetails < Struct.new( :name, :dataflow_details, :agent_status, :audit_results) SENSITIVE = [] include Aws::Structure end |
#dataflow_details ⇒ Types::UplinkDataflowDetails
Dataflow details for the uplink endpoint
3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3788 class UplinkAwsGroundStationAgentEndpointDetails < Struct.new( :name, :dataflow_details, :agent_status, :audit_results) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Uplink dataflow endpoint name
3788 3789 3790 3791 3792 3793 3794 3795 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3788 class UplinkAwsGroundStationAgentEndpointDetails < Struct.new( :name, :dataflow_details, :agent_status, :audit_results) SENSITIVE = [] include Aws::Structure end |