Class: Aws::GroundStation::Types::UplinkDataflowDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Note:

UplinkDataflowDetails is a union - when making an API calls you must set exactly one of the members.

Note:

UplinkDataflowDetails is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of UplinkDataflowDetails corresponding to the set member.

Dataflow details for an uplink endpoint

Direct Known Subclasses

AgentConnectionDetails, Unknown

Defined Under Namespace

Classes: AgentConnectionDetails, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_connection_detailsTypes::UplinkConnectionDetails

Uplink connection details for customer to Agent and Agent to Ground Station



4478
4479
4480
4481
4482
4483
4484
4485
4486
4487
# File 'lib/aws-sdk-groundstation/types.rb', line 4478

class UplinkDataflowDetails < Struct.new(
  :agent_connection_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AgentConnectionDetails < UplinkDataflowDetails; end
  class Unknown < UplinkDataflowDetails; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4478
4479
4480
# File 'lib/aws-sdk-groundstation/types.rb', line 4478

def unknown
  @unknown
end