Class: Aws::GroundStation::Waiters::ContactUpdated
- Inherits:
-
Object
- Object
- Aws::GroundStation::Waiters::ContactUpdated
- Defined in:
- lib/aws-sdk-groundstation/waiters.rb,
sig/waiters.rbs
Overview
Waits until a contact has been updated
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ ContactUpdated
constructor
A new instance of ContactUpdated.
-
#wait(params = {}) ⇒ Types::DescribeContactVersionResponse
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ ContactUpdated
Returns a new instance of ContactUpdated.
131 132 |
# File 'lib/aws-sdk-groundstation/waiters.rb', line 131
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
163 164 165 |
# File 'lib/aws-sdk-groundstation/waiters.rb', line 163 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DescribeContactVersionResponse
Returns a response object which responds to the following methods:
- #contact_id => String
- #mission_profile_arn => String
- #satellite_arn => String
- #start_time => Time
- #end_time => Time
- #pre_pass_start_time => Time
- #post_pass_end_time => Time
- #ground_station => String
- #contact_status => String
- #error_message => String
- #maximum_elevation => Types::Elevation
- #tags => Hash<String,String>
- #region => String
- #dataflow_list => Array<Types::DataflowDetail>
- #visibility_start_time => Time
- #visibility_end_time => Time
- #tracking_overrides => Types::TrackingOverrides
- #ephemeris => Types::EphemerisResponseData
- #version => Types::ContactVersion
158 |
# File 'lib/aws-sdk-groundstation/waiters.rb', line 158
def wait: (
|