Module: Aws::GroundStation::Types

Defined in:
lib/aws-sdk-groundstation/types.rb

Defined Under Namespace

Classes: AgentDetails, AggregateStatus, AntennaDemodDecodeDetails, AntennaDownlinkConfig, AntennaDownlinkDemodDecodeConfig, AntennaUplinkConfig, AwsGroundStationAgentEndpoint, AzElEphemeris, AzElEphemerisFilter, AzElProgramTrackSettings, AzElSegment, AzElSegments, AzElSegmentsData, CancelContactRequest, ComponentStatusData, ComponentVersion, ConfigDetails, ConfigIdResponse, ConfigListItem, ConfigTypeData, ConnectionDetails, ContactData, ContactIdResponse, CreateConfigRequest, CreateDataflowEndpointGroupRequest, CreateDataflowEndpointGroupV2Request, CreateDataflowEndpointGroupV2Response, CreateEndpointDetails, CreateEphemerisRequest, CreateMissionProfileRequest, DataflowDetail, DataflowEndpoint, DataflowEndpointConfig, DataflowEndpointGroupIdResponse, DataflowEndpointListItem, DecodeConfig, DeleteConfigRequest, DeleteDataflowEndpointGroupRequest, DeleteEphemerisRequest, DeleteMissionProfileRequest, DemodulationConfig, DependencyException, DescribeContactRequest, DescribeContactResponse, DescribeEphemerisRequest, DescribeEphemerisResponse, Destination, DiscoveryData, DownlinkAwsGroundStationAgentEndpoint, DownlinkAwsGroundStationAgentEndpointDetails, DownlinkConnectionDetails, DownlinkDataflowDetails, Eirp, Elevation, EndpointDetails, EphemerisData, EphemerisDescription, EphemerisErrorReason, EphemerisFilter, EphemerisIdResponse, EphemerisItem, EphemerisMetaData, EphemerisResponseData, EphemerisTypeDescription, Frequency, FrequencyBandwidth, GetAgentConfigurationRequest, GetAgentConfigurationResponse, GetAgentTaskResponseUrlRequest, GetAgentTaskResponseUrlResponse, GetConfigRequest, GetConfigResponse, GetDataflowEndpointGroupRequest, GetDataflowEndpointGroupResponse, GetMinuteUsageRequest, GetMinuteUsageResponse, GetMissionProfileRequest, GetMissionProfileResponse, GetSatelliteRequest, GetSatelliteResponse, GroundStationData, ISO8601TimeRange, IntegerRange, InvalidParameterException, KinesisDataStreamData, KmsKey, ListConfigsRequest, ListConfigsResponse, ListContactsRequest, ListContactsResponse, ListDataflowEndpointGroupsRequest, ListDataflowEndpointGroupsResponse, ListEphemeridesRequest, ListEphemeridesResponse, ListGroundStationsRequest, ListGroundStationsResponse, ListMissionProfilesRequest, ListMissionProfilesResponse, ListSatellitesRequest, ListSatellitesResponse, ListTagsForResourceRequest, ListTagsForResourceResponse, MissionProfileIdResponse, MissionProfileListItem, OEMEphemeris, ProgramTrackSettings, RangedConnectionDetails, RangedSocketAddress, RegisterAgentRequest, RegisterAgentResponse, ReserveContactRequest, ResourceInUseException, ResourceLimitExceededException, ResourceNotFoundException, S3Object, S3RecordingConfig, S3RecordingDetails, SatelliteListItem, SecurityDetails, ServiceQuotaExceededException, SocketAddress, Source, SpectrumConfig, TLEData, TLEEphemeris, TagResourceRequest, TagResourceResponse, TelemetrySinkConfig, TelemetrySinkData, TimeAzEl, TimeRange, TrackingConfig, TrackingOverrides, UntagResourceRequest, UntagResourceResponse, UpdateAgentStatusRequest, UpdateAgentStatusResponse, UpdateConfigRequest, UpdateEphemerisRequest, UpdateMissionProfileRequest, UplinkAwsGroundStationAgentEndpoint, UplinkAwsGroundStationAgentEndpointDetails, UplinkConnectionDetails, UplinkDataflowDetails, UplinkEchoConfig, UplinkSpectrumConfig

Instance Attribute Summary collapse

Instance Attribute Details

#agent_connection_detailsTypes::UplinkConnectionDetails

Uplink connection details for customer to Agent and Agent to Ground Station



1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
# File 'lib/aws-sdk-groundstation/types.rb', line 1565

class DownlinkDataflowDetails < Struct.new(
  :agent_connection_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AgentConnectionDetails < DownlinkDataflowDetails; end
  class Unknown < DownlinkDataflowDetails; end
end

#antenna_demod_decode_detailsTypes::AntennaDemodDecodeDetails

Details for antenna demod decode ‘Config` in a contact.



464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/aws-sdk-groundstation/types.rb', line 464

class ConfigDetails < Struct.new(
  :endpoint_details,
  :antenna_demod_decode_details,
  :s3_recording_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EndpointDetails < ConfigDetails; end
  class AntennaDemodDecodeDetails < ConfigDetails; end
  class S3RecordingDetails < ConfigDetails; end
  class Unknown < ConfigDetails; end
end

Information about how AWS Ground Station should configure an antenna for downlink during a contact.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-groundstation/types.rb', line 580

class ConfigTypeData < Struct.new(
  :antenna_downlink_config,
  :tracking_config,
  :dataflow_endpoint_config,
  :antenna_downlink_demod_decode_config,
  :antenna_uplink_config,
  :uplink_echo_config,
  :s3_recording_config,
  :telemetry_sink_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AntennaDownlinkConfig < ConfigTypeData; end
  class TrackingConfig < ConfigTypeData; end
  class DataflowEndpointConfig < ConfigTypeData; end
  class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end
  class AntennaUplinkConfig < ConfigTypeData; end
  class UplinkEchoConfig < ConfigTypeData; end
  class S3RecordingConfig < ConfigTypeData; end
  class TelemetrySinkConfig < ConfigTypeData; end
  class Unknown < ConfigTypeData; end
end

Information about how AWS Ground Station should configure an antenna for downlink demod decode during a contact.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-groundstation/types.rb', line 580

class ConfigTypeData < Struct.new(
  :antenna_downlink_config,
  :tracking_config,
  :dataflow_endpoint_config,
  :antenna_downlink_demod_decode_config,
  :antenna_uplink_config,
  :uplink_echo_config,
  :s3_recording_config,
  :telemetry_sink_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AntennaDownlinkConfig < ConfigTypeData; end
  class TrackingConfig < ConfigTypeData; end
  class DataflowEndpointConfig < ConfigTypeData; end
  class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end
  class AntennaUplinkConfig < ConfigTypeData; end
  class UplinkEchoConfig < ConfigTypeData; end
  class S3RecordingConfig < ConfigTypeData; end
  class TelemetrySinkConfig < ConfigTypeData; end
  class Unknown < ConfigTypeData; end
end

Information about how AWS Ground Station should configure an antenna for uplink during a contact.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-groundstation/types.rb', line 580

class ConfigTypeData < Struct.new(
  :antenna_downlink_config,
  :tracking_config,
  :dataflow_endpoint_config,
  :antenna_downlink_demod_decode_config,
  :antenna_uplink_config,
  :uplink_echo_config,
  :s3_recording_config,
  :telemetry_sink_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AntennaDownlinkConfig < ConfigTypeData; end
  class TrackingConfig < ConfigTypeData; end
  class DataflowEndpointConfig < ConfigTypeData; end
  class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end
  class AntennaUplinkConfig < ConfigTypeData; end
  class UplinkEchoConfig < ConfigTypeData; end
  class S3RecordingConfig < ConfigTypeData; end
  class TelemetrySinkConfig < ConfigTypeData; end
  class Unknown < ConfigTypeData; end
end

#az_elTypes::AzElProgramTrackSettings

Program track settings for AzElEphemeris.



1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
# File 'lib/aws-sdk-groundstation/types.rb', line 1720

class EphemerisData < Struct.new(
  :tle,
  :oem,
  :az_el,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Tle < EphemerisData; end
  class Oem < EphemerisData; end
  class AzEl < EphemerisData; end
  class Unknown < EphemerisData; end
end

#az_el_dataTypes::AzElSegments

Azimuth elevation segment data provided directly in the request.

Use this option for smaller datasets or when Amazon S3 access is not available.

Returns:



358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/aws-sdk-groundstation/types.rb', line 358

class AzElSegmentsData < Struct.new(
  :s3_object,
  :az_el_data,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3Object < AzElSegmentsData; end
  class AzElData < AzElSegmentsData; end
  class Unknown < AzElSegmentsData; end
end

#dataflow_endpoint_configTypes::DataflowEndpointConfig

Information about the dataflow endpoint ‘Config`.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-groundstation/types.rb', line 580

class ConfigTypeData < Struct.new(
  :antenna_downlink_config,
  :tracking_config,
  :dataflow_endpoint_config,
  :antenna_downlink_demod_decode_config,
  :antenna_uplink_config,
  :uplink_echo_config,
  :s3_recording_config,
  :telemetry_sink_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AntennaDownlinkConfig < ConfigTypeData; end
  class TrackingConfig < ConfigTypeData; end
  class DataflowEndpointConfig < ConfigTypeData; end
  class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end
  class AntennaUplinkConfig < ConfigTypeData; end
  class UplinkEchoConfig < ConfigTypeData; end
  class S3RecordingConfig < ConfigTypeData; end
  class TelemetrySinkConfig < ConfigTypeData; end
  class Unknown < ConfigTypeData; end
end

Definition for a downlink agent endpoint



888
889
890
891
892
893
894
895
896
897
898
899
# File 'lib/aws-sdk-groundstation/types.rb', line 888

class CreateEndpointDetails < Struct.new(
  :uplink_aws_ground_station_agent_endpoint,
  :downlink_aws_ground_station_agent_endpoint,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class UplinkAwsGroundStationAgentEndpoint < CreateEndpointDetails; end
  class DownlinkAwsGroundStationAgentEndpoint < CreateEndpointDetails; end
  class Unknown < CreateEndpointDetails; end
end

#endpoint_detailsTypes::EndpointDetails

Information about the endpoint details.



464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/aws-sdk-groundstation/types.rb', line 464

class ConfigDetails < Struct.new(
  :endpoint_details,
  :antenna_demod_decode_details,
  :s3_recording_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EndpointDetails < ConfigDetails; end
  class AntennaDemodDecodeDetails < ConfigDetails; end
  class S3RecordingDetails < ConfigDetails; end
  class Unknown < ConfigDetails; end
end

#kinesis_data_stream_dataTypes::KinesisDataStreamData

Information about a telemetry sink of type ‘KINESIS_DATA_STREAM`.



3452
3453
3454
3455
3456
3457
3458
3459
3460
3461
# File 'lib/aws-sdk-groundstation/types.rb', line 3452

class TelemetrySinkData < Struct.new(
  :kinesis_data_stream_data,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class KinesisDataStreamData < TelemetrySinkData; end
  class Unknown < TelemetrySinkData; end
end

#kms_alias_arnString

KMS Alias Arn.

Returns:

  • (String)


2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
2513
# File 'lib/aws-sdk-groundstation/types.rb', line 2500

class KmsKey < Struct.new(
  :kms_key_arn,
  :kms_alias_arn,
  :kms_alias_name,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class KmsKeyArn < KmsKey; end
  class KmsAliasArn < KmsKey; end
  class KmsAliasName < KmsKey; end
  class Unknown < KmsKey; end
end

#kms_alias_nameString

KMS Alias Name.

Returns:

  • (String)


2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
2513
# File 'lib/aws-sdk-groundstation/types.rb', line 2500

class KmsKey < Struct.new(
  :kms_key_arn,
  :kms_alias_arn,
  :kms_alias_name,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class KmsKeyArn < KmsKey; end
  class KmsAliasArn < KmsKey; end
  class KmsAliasName < KmsKey; end
  class Unknown < KmsKey; end
end

#kms_key_arnString

KMS Key Arn.

Returns:

  • (String)


2500
2501
2502
2503
2504
2505
2506
2507
2508
2509
2510
2511
2512
2513
# File 'lib/aws-sdk-groundstation/types.rb', line 2500

class KmsKey < Struct.new(
  :kms_key_arn,
  :kms_alias_arn,
  :kms_alias_name,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class KmsKeyArn < KmsKey; end
  class KmsAliasArn < KmsKey; end
  class KmsAliasName < KmsKey; end
  class Unknown < KmsKey; end
end

#oemTypes::EphemerisDescription

Description of ephemeris.



1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
# File 'lib/aws-sdk-groundstation/types.rb', line 1720

class EphemerisData < Struct.new(
  :tle,
  :oem,
  :az_el,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Tle < EphemerisData; end
  class Oem < EphemerisData; end
  class AzEl < EphemerisData; end
  class Unknown < EphemerisData; end
end

#s3_objectTypes::S3Object

The Amazon S3 object containing azimuth elevation segment data.

The Amazon S3 object must contain JSON-formatted azimuth elevation data matching the AzElSegments structure.

Returns:



358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/aws-sdk-groundstation/types.rb', line 358

class AzElSegmentsData < Struct.new(
  :s3_object,
  :az_el_data,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3Object < AzElSegmentsData; end
  class AzElData < AzElSegmentsData; end
  class Unknown < AzElSegmentsData; end
end

#s3_recording_configTypes::S3RecordingConfig

Information about an S3 recording ‘Config`.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-groundstation/types.rb', line 580

class ConfigTypeData < Struct.new(
  :antenna_downlink_config,
  :tracking_config,
  :dataflow_endpoint_config,
  :antenna_downlink_demod_decode_config,
  :antenna_uplink_config,
  :uplink_echo_config,
  :s3_recording_config,
  :telemetry_sink_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AntennaDownlinkConfig < ConfigTypeData; end
  class TrackingConfig < ConfigTypeData; end
  class DataflowEndpointConfig < ConfigTypeData; end
  class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end
  class AntennaUplinkConfig < ConfigTypeData; end
  class UplinkEchoConfig < ConfigTypeData; end
  class S3RecordingConfig < ConfigTypeData; end
  class TelemetrySinkConfig < ConfigTypeData; end
  class Unknown < ConfigTypeData; end
end

#s3_recording_detailsTypes::S3RecordingDetails

Details for an S3 recording ‘Config` in a contact.



464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/aws-sdk-groundstation/types.rb', line 464

class ConfigDetails < Struct.new(
  :endpoint_details,
  :antenna_demod_decode_details,
  :s3_recording_details,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class EndpointDetails < ConfigDetails; end
  class AntennaDemodDecodeDetails < ConfigDetails; end
  class S3RecordingDetails < ConfigDetails; end
  class Unknown < ConfigDetails; end
end

#telemetry_sink_configTypes::TelemetrySinkConfig

Information about a telemetry sink ‘Config`.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-groundstation/types.rb', line 580

class ConfigTypeData < Struct.new(
  :antenna_downlink_config,
  :tracking_config,
  :dataflow_endpoint_config,
  :antenna_downlink_demod_decode_config,
  :antenna_uplink_config,
  :uplink_echo_config,
  :s3_recording_config,
  :telemetry_sink_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AntennaDownlinkConfig < ConfigTypeData; end
  class TrackingConfig < ConfigTypeData; end
  class DataflowEndpointConfig < ConfigTypeData; end
  class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end
  class AntennaUplinkConfig < ConfigTypeData; end
  class UplinkEchoConfig < ConfigTypeData; end
  class S3RecordingConfig < ConfigTypeData; end
  class TelemetrySinkConfig < ConfigTypeData; end
  class Unknown < ConfigTypeData; end
end

#tleTypes::EphemerisDescription

Description of ephemeris.



1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
# File 'lib/aws-sdk-groundstation/types.rb', line 1720

class EphemerisData < Struct.new(
  :tle,
  :oem,
  :az_el,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Tle < EphemerisData; end
  class Oem < EphemerisData; end
  class AzEl < EphemerisData; end
  class Unknown < EphemerisData; end
end

#tracking_configTypes::TrackingConfig

Object that determines whether tracking should be used during a contact executed with this ‘Config` in the mission profile.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-groundstation/types.rb', line 580

class ConfigTypeData < Struct.new(
  :antenna_downlink_config,
  :tracking_config,
  :dataflow_endpoint_config,
  :antenna_downlink_demod_decode_config,
  :antenna_uplink_config,
  :uplink_echo_config,
  :s3_recording_config,
  :telemetry_sink_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AntennaDownlinkConfig < ConfigTypeData; end
  class TrackingConfig < ConfigTypeData; end
  class DataflowEndpointConfig < ConfigTypeData; end
  class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end
  class AntennaUplinkConfig < ConfigTypeData; end
  class UplinkEchoConfig < ConfigTypeData; end
  class S3RecordingConfig < ConfigTypeData; end
  class TelemetrySinkConfig < ConfigTypeData; end
  class Unknown < ConfigTypeData; end
end

Definition for an uplink agent endpoint



888
889
890
891
892
893
894
895
896
897
898
899
# File 'lib/aws-sdk-groundstation/types.rb', line 888

class CreateEndpointDetails < Struct.new(
  :uplink_aws_ground_station_agent_endpoint,
  :downlink_aws_ground_station_agent_endpoint,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class UplinkAwsGroundStationAgentEndpoint < CreateEndpointDetails; end
  class DownlinkAwsGroundStationAgentEndpoint < CreateEndpointDetails; end
  class Unknown < CreateEndpointDetails; end
end

Information about an uplink echo ‘Config`.

Parameters from the ‘AntennaUplinkConfig`, corresponding to the specified ` AntennaUplinkConfigArn`, are used when this `UplinkEchoConfig` is used in a contact.



580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/aws-sdk-groundstation/types.rb', line 580

class ConfigTypeData < Struct.new(
  :antenna_downlink_config,
  :tracking_config,
  :dataflow_endpoint_config,
  :antenna_downlink_demod_decode_config,
  :antenna_uplink_config,
  :uplink_echo_config,
  :s3_recording_config,
  :telemetry_sink_config,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class AntennaDownlinkConfig < ConfigTypeData; end
  class TrackingConfig < ConfigTypeData; end
  class DataflowEndpointConfig < ConfigTypeData; end
  class AntennaDownlinkDemodDecodeConfig < ConfigTypeData; end
  class AntennaUplinkConfig < ConfigTypeData; end
  class UplinkEchoConfig < ConfigTypeData; end
  class S3RecordingConfig < ConfigTypeData; end
  class TelemetrySinkConfig < ConfigTypeData; end
  class Unknown < ConfigTypeData; end
end