Class: Aws::GroundStation::Types::GetMinuteUsageRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::GetMinuteUsageRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Input for the ‘GetMinuteUsage` operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#month ⇒ Integer
The month being requested, with a value of 1-12.
-
#year ⇒ Integer
The year being requested, in the format of YYYY.
Instance Attribute Details
#month ⇒ Integer
The month being requested, with a value of 1-12.
2482 2483 2484 2485 2486 2487 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2482 class GetMinuteUsageRequest < Struct.new( :month, :year) SENSITIVE = [] include Aws::Structure end |
#year ⇒ Integer
The year being requested, in the format of YYYY.
2482 2483 2484 2485 2486 2487 |
# File 'lib/aws-sdk-groundstation/types.rb', line 2482 class GetMinuteUsageRequest < Struct.new( :month, :year) SENSITIVE = [] include Aws::Structure end |