Class: Aws::GroundStation::Types::ListContactsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-groundstation/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_timeTime

End time of a contact in UTC.

Returns:

  • (Time)


2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-groundstation/types.rb', line 2590

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#ephemerisTypes::EphemerisFilter

Filter for selecting contacts that use a specific ephemeris“.



2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-groundstation/types.rb', line 2590

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#ground_stationString

Name of a ground station.

Returns:

  • (String)


2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-groundstation/types.rb', line 2590

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Maximum number of contacts returned.

Returns:

  • (Integer)


2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-groundstation/types.rb', line 2590

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#mission_profile_arnString

ARN of a mission profile.

Returns:

  • (String)


2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-groundstation/types.rb', line 2590

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

Next token returned in the request of a previous ListContacts call. Used to get the next page of results.

Returns:

  • (String)


2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-groundstation/types.rb', line 2590

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#satellite_arnString

ARN of a satellite.

Returns:

  • (String)


2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-groundstation/types.rb', line 2590

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

Start time of a contact in UTC.

Returns:

  • (Time)


2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-groundstation/types.rb', line 2590

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end

#status_listArray<String>

Status of a contact reservation.

Returns:

  • (Array<String>)


2590
2591
2592
2593
2594
2595
2596
2597
2598
2599
2600
2601
2602
# File 'lib/aws-sdk-groundstation/types.rb', line 2590

class ListContactsRequest < Struct.new(
  :max_results,
  :next_token,
  :status_list,
  :start_time,
  :end_time,
  :ground_station,
  :satellite_arn,
  :mission_profile_arn,
  :ephemeris)
  SENSITIVE = []
  include Aws::Structure
end