Class: Aws::GroundStation::Types::ListGroundStationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::ListGroundStationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Input for the ListGroundStations operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
Maximum number of ground stations returned.
-
#next_token ⇒ String
Next token that can be supplied in the next call to get the next page of ground stations.
-
#satellite_id ⇒ String
Satellite ID to retrieve on-boarded ground stations.
Instance Attribute Details
#max_results ⇒ Integer
Maximum number of ground stations returned.
3223 3224 3225 3226 3227 3228 3229 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3223 class ListGroundStationsRequest < Struct.new( :satellite_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
Next token that can be supplied in the next call to get the next page of ground stations.
3223 3224 3225 3226 3227 3228 3229 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3223 class ListGroundStationsRequest < Struct.new( :satellite_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#satellite_id ⇒ String
Satellite ID to retrieve on-boarded ground stations.
3223 3224 3225 3226 3227 3228 3229 |
# File 'lib/aws-sdk-groundstation/types.rb', line 3223 class ListGroundStationsRequest < Struct.new( :satellite_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |