Class: Aws::GroundStation::Types::UpdateContactRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::GroundStation::Types::UpdateContactRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-groundstation/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
A client token is a unique, case-sensitive string of up to 64 ASCII characters.
-
#contact_id ⇒ String
UUID of a contact.
-
#satellite_arn ⇒ String
ARN of a satellite.
-
#tracking_overrides ⇒ Types::TrackingOverrides
Overrides the default tracking configuration on an antenna during a contact.
Instance Attribute Details
#client_token ⇒ String
A client token is a unique, case-sensitive string of up to 64 ASCII characters. It is generated by the client to ensure idempotent operations, allowing safe retries without unintended side effects.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
4273 4274 4275 4276 4277 4278 4279 4280 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4273 class UpdateContactRequest < Struct.new( :contact_id, :client_token, :tracking_overrides, :satellite_arn) SENSITIVE = [] include Aws::Structure end |
#contact_id ⇒ String
UUID of a contact.
4273 4274 4275 4276 4277 4278 4279 4280 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4273 class UpdateContactRequest < Struct.new( :contact_id, :client_token, :tracking_overrides, :satellite_arn) SENSITIVE = [] include Aws::Structure end |
#satellite_arn ⇒ String
ARN of a satellite.
4273 4274 4275 4276 4277 4278 4279 4280 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4273 class UpdateContactRequest < Struct.new( :contact_id, :client_token, :tracking_overrides, :satellite_arn) SENSITIVE = [] include Aws::Structure end |
#tracking_overrides ⇒ Types::TrackingOverrides
Overrides the default tracking configuration on an antenna during a contact.
4273 4274 4275 4276 4277 4278 4279 4280 |
# File 'lib/aws-sdk-groundstation/types.rb', line 4273 class UpdateContactRequest < Struct.new( :contact_id, :client_token, :tracking_overrides, :satellite_arn) SENSITIVE = [] include Aws::Structure end |